@@ -1,5 +1,5 @@
 # bind global variables
-if (getRversion() >= "2.15.1") utils::globalVariables(c("pv"))
+utils::globalVariables(c("pv"))
 
 
 #' @title Plot One-Way-Anova tables
@@ -12,72 +12,46 @@ if (getRversion() >= "2.15.1") utils::globalVariables(c("pv"))
 #'                
 #' @seealso \code{\link{sjt.grpmean}}
 #'                
-#' @param depVar The dependent variable. Will be used with following formular:
+#' @param depVar dependent variable. Will be used with following formula:
 #'          \code{aov(depVar ~ grpVar)}
-#' @param grpVar The grouping variable, as unordered factor. Will be used with following formular:
+#' @param grpVar grouping variable, as unordered factor. Will be used with following formula:
 #'          \code{aov(depVar ~ grpVar)}
-#' @param meansums If \code{TRUE}, the values reported are the true group mean values (see also \code{\link{sjt.grpmean}}).
+#' @param meansums logical, if \code{TRUE}, the values reported are the true group mean values (see also \code{\link{sjt.grpmean}}).
 #'          If \code{FALSE} (default), the values are reported in the standard way, i.e. the values indicate the difference of
 #'          the group mean in relation to the intercept (reference group).
-#' @param type Indicates Whether the group means should be plotted as \code{"dots"} (aka forest plots, default)
-#'          or as \code{"bars"}.
-#' @param hideErrorBars If \code{TRUE}, the error bars that indicate the confidence intervals of the group means are not
+#' @param type plot type, whether group means should be plotted as \code{"dots"} (aka forest plots, default)
+#'          or as \code{"bars"}
+#' @param hideErrorBars logical, if \code{TRUE}, the error bars that indicate the confidence intervals of the group means are not
 #'          shown. Only applies if parameter \code{type} is \code{"bars"}. Default value is \code{FALSE}.
-#' @param title Diagram's title as string.
-#'          Example: \code{title = "my title"}
-#'          Use \code{"NULL"} to automatically detect variable names that will be used as title
-#'          (see \code{\link[sjmisc]{set_var_labels}}) for details). Use \code{title=""} for a blank title.
-#' @param axisLabels.y Value labels of the grouping variable \code{grpVar} that are used for labelling the
-#'          grouping variable axis. Passed as vector of strings.
-#'          Example: \code{axisLabels.y=c("Label1", "Label2", "Label3")}. \cr
-#'          \strong{Note:} If you use the \code{\link[sjmisc]{read_spss}} function and the \code{\link[sjmisc]{get_val_labels}} function, you receive a
-#'          list object with label string. The labels may also be passed as list object. They will be coerced
-#'          to character vector automatically. See examples below. \cr
-#'          \strong{Note:} In case \code{type = "bars"}, \code{grpVar} will be plotted along
-#'          the x-axis.
-#' @param reverseOrder If \code{TRUE}, the order of the factor categories (groups) is reversed.
+#' @param axisLabels.y character vector, indicating the value labels of \code{grpVar} that 
+#'          are used for labelling the axis. See 'Examples'.
+#' @param reverseOrder logical, if \code{TRUE}, the order of categories (groups) is reversed.
 #'          Default is \code{FALSE}.
-#' @param stringIntercept A string that indicates the reference group (intercept), that is appended to
+#' @param stringIntercept string that indicates the reference group (intercept), that is appended to
 #'          the value label of the grouping variable. Default is \code{"(Intercept)"}.
-#' @param showAxisLabels.y Whether y axis text (category value) should be shown (use \code{TRUE})
-#'          or not. Default is \code{TRUE}.
-#' @param axisTitle.x A label for the x axis. Default is \code{""}, which means no x-axis title.
-#'          Use \code{NULL} to automatically detect variable names that will be used as title
-#'          (see \code{\link[sjmisc]{set_var_labels}}) for details).
-#' @param axisLimits Defines the range of the axis where the beta coefficients and their confidence intervalls
-#'          are drawn. By default, the limits range from the lowest confidence interval to the highest one, so
-#'          the diagram has maximum zoom. Use your own values as 2-value-vector, for instance: \code{limits=c(-0.8,0.8)}.
+#' @param axisLimits numeric vector of length 2, defining the range of the plot axis.
+#'          By default, the limits range from the lowest confidence interval to the 
+#'          highest, so plot has maximum zoom.
 #' @param errorBarColor The color of the error bars that indicate the confidence intervalls
-#'          of the group means. Default is \code{NULL}, which means that if \code{type} is \code{"dots"},
-#'          the \code{pointColor} value will be used as error bar color. In case \code{type} is \code{"bars"},
-#'          \code{"black"} will be used as error bar color.
-#' @param geom.colors The colors of the points resp. bars (depending on \code{type}) that indicate the mean-value. 
-#'          \code{geom.colors} is a 
-#'          vector with two values: the first indicating groups with positive means and the second 
-#'          indicating negative means. Default is \code{c("#3366a0", "#aa6633")}.
-#' @param geom.size The size of the points resp. bars (depending on \code{type}) that indicate the 
-#'          mean-value. Default is 3, which is suitable for \code{type="dots"}. Use something like
-#'          0.5 is \code{type="bars"}.
-#' @param breakTitleAt Wordwrap for diagram title. Determines how many chars of the title are displayed in
-#'          one line and when a line break is inserted into the title
-#' @param breakLabelsAt Wordwrap for diagram labels. Determines how many chars of the category labels are displayed in 
-#'          one line and when a line break is inserted
-#' @param gridBreaksAt Sets the breaks on the y axis, i.e. at every n'th position a major
-#'          grid is being printed. Default is \code{NULL}, so \code{\link{pretty}} gridbeaks will be used.
-#' @param expand.grid If \code{TRUE}, the plot grid is expanded, i.e. there is a small margin between
-#'          axes and plotting region. Default is \code{FALSE}.
-#' @param showValueLabels Whether the value labels (mean differences) should be plotted 
+#'          of the group means. Default is \code{NULL}, which means that if \code{type = "dots"},
+#'          the \code{pointColor} value will be used as errorbar color. In case \code{type = "bars"},
+#'          \code{"black"} will be used as errorbar color.
+#' @param geom.colors vector of length two, indicating the colors of the points resp. 
+#'          bars (depending on \code{type}); first value is for groups with positive 
+#'          means and the second for negative means.
+#' @param geom.size size of the points resp. bars (depending on \code{type}) that indicate the 
+#'          mean-value. Default is 3, which is suitable for \code{type = "dots"}. Use something like
+#'          0.5 is \code{type = "bars"}.
+#' @param showValueLabels logical, whether the value labels (mean differences) should be plotted 
 #'          to each dot or not.
-#' @param labelDigits The amount of digits for rounding the estimations (see \code{showValueLabels}).
-#'          Default is 2, i.e. estimators have 2 digits after decimal point.
-#' @param showPValueLabels Whether the significance levels of each category/group should be appended
-#'          to values or not.
-#' @param showModelSummary If \code{TRUE} (default), a summary of the anova model with 
+#' @param showModelSummary logical, if \code{TRUE}, a summary of the anova model with 
 #'          Sum of Squares between groups (ssb), Sum of Squares within groups (ssw), multiple and adjusted 
 #'          R-square and F-Test is printed to the lower right corner
 #'          of the diagram. Default is \code{TRUE}.
-#' @param printPlot If \code{TRUE} (default), plots the results as graph. Use \code{FALSE} if you don't
-#'          want to plot any graphs. In either case, the ggplot-object will be returned as value.
+#'          
+#' @inheritParams sjp.grpfrq
+#' @inheritParams sjp.lm
+#'          
 #' @return (Insisibily) returns the ggplot-object with the complete plot (\code{plot}) as well as the data frame that
 #'           was used for setting up the ggplot-object (\code{df}).
 #' 
@@ -95,7 +69,8 @@ if (getRversion() >= "2.15.1") utils::globalVariables(c("pv"))
 #' sjp.aov1(efc$c12hour,
 #'          as.factor(efc$e42dep),
 #'          axisLabels.y = efc.val['e42dep'],
-#'          axisTitle.x = efc.var[['c12hour']])
+#'          axisTitle.x = efc.var[['c12hour']],
+#'          showModelSummary = TRUE)
 #'          
 #' # -------------------------------------------------
 #' # auto-detection of value labels and variable names
@@ -112,36 +87,36 @@ if (getRversion() >= "2.15.1") utils::globalVariables(c("pv"))
 #'          axisLabels.y = efc.val['c172code'],
 #'          title = efc.var[['c12hour']],
 #'          type = "bars",
-#'          geom.size = 0.5,
-#'          showModelSummary = FALSE)
+#'          geom.size = 0.5)
 #'
 #' @import ggplot2
 #' @import sjmisc
+#' @importFrom stats confint aov summary.lm
 #' @export
 sjp.aov1 <- function(depVar,
-                    grpVar,
-                    meansums=FALSE,
-                    type="dots",
-                    hideErrorBars=FALSE,
-                    title=NULL,
-                    axisLabels.y=NULL, 
-                    reverseOrder=FALSE,
-                    stringIntercept="(Intercept)",
-                    showAxisLabels.y=TRUE,
-                    axisTitle.x="",
-                    axisLimits=NULL,
-                    errorBarColor=NULL,
-                    geom.colors=c("#3366a0", "#aa3333"),
-                    geom.size=3,
-                    breakTitleAt=50, 
-                    breakLabelsAt=25, 
-                    gridBreaksAt=NULL,
-                    expand.grid=FALSE,
-                    showValueLabels=TRUE, 
-                    labelDigits=2,
-                    showPValueLabels=TRUE,
-                    showModelSummary=TRUE,
-                    printPlot=TRUE) {
+                     grpVar,
+                     meansums = FALSE,
+                     type = "dots",
+                     hideErrorBars = FALSE,
+                     title = NULL,
+                     axisLabels.y = NULL,
+                     reverseOrder = FALSE,
+                     stringIntercept = "(Intercept)",
+                     showAxisLabels.y = TRUE,
+                     axisTitle.x = "",
+                     axisLimits = NULL,
+                     errorBarColor = NULL,
+                     geom.colors = c("#3366a0", "#aa3333"),
+                     geom.size = 3,
+                     breakTitleAt = 50,
+                     breakLabelsAt = 25,
+                     gridBreaksAt = NULL,
+                     expand.grid = FALSE,
+                     showValueLabels = TRUE,
+                     labelDigits = 2,
+                     showPValueLabels = TRUE,
+                     showModelSummary = FALSE,
+                     printPlot = TRUE) {
   # --------------------------------------------------------
   # try to automatically set labels is not passed as parameter
   # --------------------------------------------------------
@@ -211,15 +186,15 @@ sjp.aov1 <- function(depVar,
   # only one group variable, Type of SS does
   # not matter.
   # ----------------------------
-  fit <- aov(depVar ~ grpVar)
+  fit <- stats::aov(depVar ~ grpVar)
   # coefficients (group mean)
-  means <- summary.lm(fit)$coefficients[, 1]
+  means <- stats::summary.lm(fit)$coefficients[, 1]
   # p-values of means
-  means.p <- summary.lm(fit)$coefficients[, 4]
+  means.p <- stats::summary.lm(fit)$coefficients[, 4]
   # lower confidence intervals of coefficients (group mean)
-  means.lci <- confint(fit)[, 1]
+  means.lci <- stats::confint(fit)[, 1]
   # upper confidence intervals of coefficients (group mean)
-  means.uci <- confint(fit)[, 2]
+  means.uci <- stats::confint(fit)[, 2]
   # ----------------------------
   # Check whether true group means should be reported
   # or the differences of group means in relation to the
@@ -240,11 +215,11 @@ sjp.aov1 <- function(depVar,
     # sum of squares
     ss <- summary(fit)[[1]]['Sum Sq']
     # multiple r2
-    r2 <- summary.lm(fit)$r.squared
+    r2 <- stats::summary.lm(fit)$r.squared
     # adj. r2
-    r2.adj <- summary.lm(fit)$adj.r.squared
+    r2.adj <- stats::summary.lm(fit)$adj.r.squared
     # get F-statistics
-    fstat <- summary.lm(fit)$fstatistic[1]
+    fstat <- stats::summary.lm(fit)$fstatistic[1]
     # p-value for F-test
     pval <- summary(fit)[[1]]['Pr(>F)'][1, 1]
     # indicate significance level by stars
