@@ -1,6 +1,5 @@
 # bind global variables
-if (getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci", "lower.ci", "ia", "..density.."))
-
+utils::globalVariables(c("frq", "grp", "upper.ci", "lower.ci", "ia", "..density.."))
 
 
 #' @title Plot frequencies of (count) variables
@@ -12,135 +11,103 @@ if (getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci"
 #'          }
 #' 
 #' @description Plot frequencies of a (count) variable as bar graph, histogram,
-#'                box plot etc. using ggplot.
+#'                box plot etc.
 #' 
 #' @note This function only works with variables with integer values, i.e. scales / centred variables
 #'         with decimales may result in unexpected behaviour.
 #' 
-#' @param varCount The variable which frequencies should be plotted.
-#' @param title Title of diagram as string. Example: \code{title = "my title"}.
-#'          Use \code{NULL} to automatically detect variable names that will be used as title
-#'          (see \code{\link[sjmisc]{set_var_labels}}) for details).
-#' @param weightBy A weight factor that will be applied to weight all cases from \code{varCount}.
+#' @param varCount a vector of values (variable) describing the bars which make up the plot.
+#' @param weightBy weight factor that will be applied to weight all cases of \code{varCount}.
 #'          Must be a vector of same length as \code{varCount}. Default is \code{NULL}, so no weights are used.
-#' @param weightByTitleString If a weight factor is supplied via the parameter \code{weightBy}, the diagram's title
-#'          may indicate this with a remark. Default is \code{NULL}, so the diagram's title will not be modified when
-#'          cases are weighted. Use a string as parameter, e.g.: \code{weightByTitleString=" (weighted)"}.
-#' @param interactionVar An interaction variable which can be used for box plots. Divides the observations in 
-#'          \code{varCount} into the factors (sub groups) of \code{interactionVar}. Only applies when parameter \code{"type"}
-#'          is \code{"box"} or \code{"violin"} (resp. their alternative strings like \code{"boxplot"}, \code{"boxplots"} or \code{"v"}).
-#' @param sort.frq Determines whether categories on x-axis should be sorted according to the frequencies or not. 
-#'          Default is \code{"none"}, so categories are not sorted by frequency. Use \code{"asc"} or
-#'          \code{"desc"} for sorting categories ascending or descending in relation to the frequencies.
+#' @param interactionVar an interaction variable which can be used for box plots. Divides the observations in 
+#'          \code{varCount} into sub groups indicated by \code{interactionVar}. Only 
+#'          applies when \code{type = "boxplots"} or \code{"violins"}.
+#' @param sort.frq Determines whether categories (bars) on x-axis should be sorted 
+#'          according to the frequencies or not.  Default is \code{"none"}, so 
+#'          categories are not sorted by frequency. Use \code{"asc"} or
+#'          \code{"desc"} for sorting categories ascending or descending order.
 #' @param type Specifies the type of distribution plot that will be plotted.
 #'          \describe{
-#'            \item{\code{"bar"}}{or \code{"bars"} or \code{"b"} for simple bars (the default setting)}
-#'            \item{\code{"dots"}}{or \code{"dot"} for a dot plot}
-#'            \item{\code{"h"}}{or \code{"hist"} or \code{"histogram"} for a histogram}
-#'            \item{\code{"line"}}{or \code{"lines"} or \code{"l"} for a histogram with filled area with line}
-#'            \item{\code{"dens"}}{or \code{"d"} or \code{"density"} for a density plot}
-#'            \item{\code{"box"}}{or \code{"boxplot"} or \code{"boxplots"} for box plots}
-#'            \item{\code{"v"}}{or \code{"violin"} for violin plots}
+#'            \item{\code{"bars"}}{for simple bars (the default setting)}
+#'            \item{\code{"dots"}}{for a dot plot}
+#'            \item{\code{"histogram"}}{for a histogram}
+#'            \item{\code{"lines"}}{for a line-styled histogram with filled area}
+#'            \item{\code{"density"}}{for a density plot}
+#'            \item{\code{"boxplots"}}{for box plots}
+#'            \item{\code{"violins"}}{for violin plots}
 #'            }
+#'            You may use initial letter for \code{type} options, except for
+#'            \code{type = "dots"} and \code{type = "boxplots"}, which may be abbreviated
+#'            with \code{type = "dot"} and \code{type = "box"}
 #' @param geom.colors user defined color for geoms, e.g. \code{geom.colors = "#0080ff"}.
-#' @param geom.size size of geoms, depending on the plot \code{type}. Note that 
-#'          bar and bin widths mostly need smaller values than dot sizes (i.e. if \code{type = "dots"}).
-#' @param axisLabels.x Labels for the x-axis breaks.
-#'          Example: \code{axisLabels.x = c("Label1", "Label2", "Label3")}. \cr
-#'          \strong{Note:} If you use the \code{\link[sjmisc]{read_spss}} function and the \code{\link[sjmisc]{get_val_labels}} function, you receive a
-#'          list object with label string. The labels may also be passed as list object. They will be coerced
-#'          to character vector automatically.
-#' @param interactionVarLabels Labels for the x-axis breaks when having interaction variables included.
-#'          These labels replace the \code{axisLabels.x}. Only applies, when using box or violin plots
-#'          (i.e. \code{type} is \code{"box"} or \code{"violin"}) and \code{interactionVar} is not \code{NULL}.
-#'          Example: See \code{axisLabels.x}.
-#' @param axisLimits.y A numeric vector of length two, defining lower and upper axis limits
-#'          of the y scale. By default, this parameter is set to \code{NULL}, i.e. the 
-#'          y-axis ranges from 0 to required maximum.
-#' @param breakTitleAt Determines how many chars of the title are displayed in 
-#'          one line and when a line break is inserted into the title.
-#' @param breakLabelsAt Determines how many chars of the labels are displayed in 
-#'          one line and when a line break is inserted into the axis labels.
-#' @param gridBreaksAt Sets the breaks on the y axis, i.e. at every n'th position a major
-#'          grid is being printed.
-#' @param innerBoxPlotWidth The width of the inner box plot that is plotted inside of violin plots. Only applies 
-#'          if \code{type = "violin"}. Default value is 0.15
-#' @param innerBoxPlotDotSize Size of mean dot insie a violin plot. Applies only when \code{type} is set to \code{"violin"} or \code{"box"}.
-#' @param expand.grid If \code{TRUE}, the plot grid is expanded, i.e. there is a small margin between
-#'          axes and plotting region. Default is \code{FALSE}.
-#' @param showValueLabels Whether counts and percentage values should be plotted to each bar. Default
-#'          is \code{TRUE}.
-#' @param showCountValues If \code{TRUE} (default), count values are be plotted to each bar. If \code{FALSE},
-#'          count values are removed.
-#' @param showPercentageValues If \code{TRUE} (default), percentage values are be plotted to each bar, if \code{FALSE},
-#'          percentage-values are removed.
-#' @param showAxisLabels.x Whether x-axis labels (category names) should be shown or not.
-#' @param showAxisLabels.y Whether y-axis labels (count values) should be shown or not.
-#' @param showCI logical, whether or not confidence intervals should be plotted. Only applies to \code{type = "dots"}
-#'          or \code{type = "bars"}.
-#' @param error.bar.color Color of confidence interval bars (error bars). Only applies to \code{type = "bars"}. In case
-#'          of dot plots, error bars will have same colors as dots (see \code{geom.colors}).
-#' @param showMeanIntercept If \code{TRUE}, a vertical line in histograms is drawn to indicate the mean value of the count
-#'          variables. Only applies to histogram-charts.
-#' @param showMeanValue If \code{TRUE} (default value), the mean value is printed to the vertical line that indicates the mean value
+#' @param interactionVarLabels a character vector with labels for the x-axis breaks 
+#'          when having interaction variables included. These labels replace the 
+#'          \code{axisLabels.x}. Only applies, when using box or violin plots
+#'          (i.e. \code{type = "boxplots"} or \code{"violins"}) and \code{interactionVar} 
+#'          is not \code{NULL}.
+#' @param showCI logical, whether or not confidence intervals should be plotted. 
+#'          Only applies to \code{type = "dots"} or \code{type = "bars"}.
+#' @param error.bar.color color of confidence interval bars (error bars). 
+#'          Only applies to \code{type = "bars"}. In case of dot plots, error bars 
+#'          will have same colors as dots (see \code{geom.colors}).
+#' @param showMeanIntercept logical, if \code{TRUE}, a vertical line in histograms 
+#'          is drawn to indicate the mean value of the count variables. Only 
+#'          applies to histogram-charts.
+#' @param showMeanValue logical, if \code{TRUE} (default), the mean value 
+#'          is printed to the vertical line that indicates the mean value
 #'          of the count variables. Only applies to histogram-charts.
-#' @param showStandardDeviation If \code{TRUE}, the standard deviation is annotated as shaded rectangle around the mean intercept
+#' @param showStandardDeviation logical, if \code{TRUE}, the standard deviation 
+#'          is annotated as shaded rectangle around the mean intercept
 #'          line. Only applies to histogram-charts.
-#' @param meanInterceptLineType The linetype of the mean intercept line. Only applies to histogram-charts and 
-#'          when \code{showMeanIntercept} is \code{TRUE}.
-#' @param meanInterceptLineSize The size of the mean intercept line. Only applies to histogram-charts and when 
-#'          \code{showMeanIntercept} is \code{TRUE}.
-#' @param showNormalCurve If \code{TRUE}, a normal curve, which is adjusted to the data,
+#' @param meanInterceptLineType numeric value, indicating the linetype of the mean 
+#'          intercept line. Only applies to histogram-charts and 
+#'          when \code{showMeanIntercept = TRUE}.
+#' @param meanInterceptLineSize numeric, size of the mean intercept line. Only 
+#'          applies to histogram-charts and when \code{showMeanIntercept = TRUE}.
+#' @param showNormalCurve logical, if \code{TRUE}, a normal curve, which is adjusted to the data,
 #'          is plotted over the histogram or density plot. Default is
 #'          \code{FALSE}. Only applies when histograms or density plots are plotted (see \code{type}).
-#' @param showStandardNormalCurve If \code{TRUE}, a normal curve, which is not adjusted to the data (thus
-#'          representing a "true" standard normal curve, which is, however, still an approximation),
-#'          is plotted over the histogram or density plot. Default is \code{FALSE}. Only applies when 
+#' @param showStandardNormalCurve logical, if \code{TRUE}, a normal curve, which is not 
+#'          adjusted to the data (thus representing a "true" standard normal curve, 
+#'          which is, however, still an approximation), is plotted over the histogram 
+#'          or density plot. Default is \code{FALSE}. Only applies when 
 #'          histograms or density plots are plotted (see \code{type}).
-#' @param adjustNormalCurve.x If \code{TRUE} and \code{showStandardNormalCurve} is also \code{TRUE}, the 
+#' @param adjustNormalCurve.x logical, if \code{TRUE} and \code{showStandardNormalCurve} is also \code{TRUE}, the 
 #'          x-axis-start of the standard normal curve starts with the x-axis limits of the graph. This
 #'          is only necessary, if minimum value of \code{varCount} is larger than 0 or 1.
-#' @param normalCurveColor Specify the color of the normal curve line. Only
-#'          applies if \code{showNormalCurve} is \code{TRUE}.
-#' @param normalCurveSize Specifiy the size of the normal curve line. Only
-#'          applies if \code{showNormalCurve} is \code{TRUE}.
-#' @param normalCurveAlpha Specify the transparancy (alpha value) of the normal curve. Only
-#'          applies if \code{showNormalCurve} is \code{TRUE}.
-#' @param axisTitle.x label for the x-axis. useful when plotting histograms with metric scales where no category labels
-#'          are assigned to the x-axis. By default, \code{""} is used, i.e. no title
-#'          is printed.
-#'          Use \code{NULL} to automatically detect variable names that will be used as title
-#'          (see \code{\link[sjmisc]{set_var_labels}}) for details).
-#' @param axisTitle.y label for the y-axis. useful when plotting histograms with metric scales where no category labels
-#'          are assigned to the y-axis. By default, \code{""} is used, i.e. no title
-#'          is printed.
-#'          Use \code{NULL} to automatically detect variable names that will be used as title
-#'          (see \code{\link[sjmisc]{set_var_labels}}) for details).
-#' @param hist.skipZeros If \code{TRUE}, zero counts (categories with no answer) in \code{varCount} are omitted
-#'          when drawing histrograms, and the mapping is changed to \code{\link[ggplot2]{stat_bin}}. Only applies to 
-#'          histograms (see \code{type}). Use this parameter to get identical results to the default
-#'          \code{\link[ggplot2]{qplot}} or \code{\link[ggplot2]{geom_histogram}} histogram plots of ggplot. You may need
-#'          to adjust the \code{geom.size} parameter for better visual results (which, by ggplot-default, is
-#'          1/30 of the x-axis-range).
-#' @param startAxisAt Determines the first value on the x-axis. By default, this value is set
-#'          to \code{"auto"}, i.e. the value range on the x axis starts with the lowest value of \code{varCount}.
-#'          If you set \code{startAxisAt} to 1, you may have zero counts if the lowest value of \code{varCount}
-#'          is larger than 1 and hence no bars plotted for these values in such cases.
-#' @param autoGroupAt A value indicating at which length of unique values of \code{varCount} the variable
-#'          is automatically grouped into smaller units (see \code{\link[sjmisc]{group_var}}). If \code{varCount} has large 
-#'          numbers of unique values, too many bars for the graph have to be plotted. Hence it's recommended 
-#'          to group such variables. For example, if \code{autoGroupAt} is 50, i.e. if \code{varCount} has 50 and more unique values 
-#'          it will be grouped using \code{group_var} with \code{groupsize = "auto"} parameter. By default, 
-#'          the maximum group count is 30. However, if \code{autoGroupAt} is less than 30, \code{autoGroupAt} 
-#'          groups are built. Default value for \code{autoGroupAt} is \code{NULL}, i.e. auto-grouping is off.
-#' @param coord.flip If \code{TRUE}, the x and y axis are swapped. Default is \code{FALSE}.
-#' @param labelPos If \code{coord.flip} is \code{TRUE}, use this parameter to specify value label position.
+#' @param normalCurveColor color of the normal curve line. Only
+#'          applies if \code{showNormalCurve = TRUE}.
+#' @param normalCurveSize numeric, size of the normal curve line. Only
+#'          applies if \code{showNormalCurve = TRUE}.
+#' @param normalCurveAlpha transparancy level (alpha value) of the normal curve. Only
+#'          applies if \code{showNormalCurve = TRUE}.
+#' @param axisTitle.x title for the x-axis. By default, the variable name will be 
+#'          automatically detected and used as title (see \code{\link[sjmisc]{set_var_labels}}) 
+#'          for details).
+#' @param axisTitle.y title for the y-axis. By default, this value is \code{NULL},
+#'          i.e. no title is printed.
+#' @param hist.skipZeros logical, if \code{TRUE}, zero counts (categories with no answer) 
+#'          in \code{varCount} are omitted when drawing histrograms, and the mapping 
+#'          is changed to \code{\link[ggplot2]{stat_bin}}. Only applies to  histograms. 
+#'          Use this parameter to get similar results to the default \code{\link[ggplot2]{qplot}} 
+#'          or \code{\link[ggplot2]{geom_histogram}} histogram plots of ggplot. You may need
+#'          to adjust the \code{geom.size} parameter for better visual results 
+#'          (which, by ggplot-default, is 1/30 of the x-axis-range).
+#' @param autoGroupAt numeric value, indicating at which length of unique values of \code{varCount}, 
+#'          automatic grouping into smaller units is done (see \code{\link[sjmisc]{group_var}}).
+#'          If \code{varCount} has large numbers of unique values, there may be too many bars 
+#'          for the plot. Hence it's practical to group such variables. For example, 
+#'          if \code{autoGroupAt = 50} and \code{varCount} has more than 50 unique values,
+#'          it will be grouped (using the \code{\link[sjmisc]{group_var}} function). 
+#'          Default value for \code{autoGroupAt} is \code{NULL}, i.e. auto-grouping is off.
+#'          See \code{\link[sjmisc]{group_var}} for examples on grouping.
+#' @param labelPos string, indicating the position of value labels, when \code{coord.flip = TRUE}.
 #'          Can be either \code{"inside"} or \code{"outside"} (default). You may specify
-#'          initial letter only. If \code{coord.flip} is \code{FALSE}, this parameter will
+#'          initial letter only. If \code{coord.flip = FALSE}, this parameter will
 #'          be ignored.
-#' @param na.rm If \code{TRUE}, missings are not included in the frequency calculation and diagram plot.
-#' @param printPlot If \code{TRUE} (default), plots the results as graph. Use \code{FALSE} if you don't
-#'          want to plot any graphs. In either case, the ggplot-object will be returned as value.
+#'          
+#' @inheritParams sjp.grpfrq
+#' 
 #' @return (Insisibily) returns the ggplot-object with the complete plot (\code{plot}) as well as the data frame that
 #'           was used for setting up the ggplot-object (\code{mydf}).
 #' 
@@ -222,7 +189,6 @@ if (getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci"
 #'         type = "dots",
 #'         showCI = TRUE,
 #'         sort.frq = "desc",
-#'         geom.size = 3,
 #'         coord.flip = TRUE)
 #' 
 #' # -------------------------------------------------
@@ -237,52 +203,54 @@ if (getRversion() >= "2.15.1") utils::globalVariables(c("frq", "grp", "upper.ci"
 #'   
 #' @import ggplot2
 #' @import sjmisc
+#' @importFrom stats na.omit sd weighted.mean
 #' @export
-sjp.frq <- function(varCount, 
-                    title="",
-                    weightBy=NULL,
-                    weightByTitleString=NULL,
-                    interactionVar=NULL,
-                    sort.frq="none",
-                    type="bars",
-                    geom.size=0.7,
-                    geom.colors=NULL,
-                    axisLabels.x=NULL, 
-                    interactionVarLabels=NULL,
+sjp.frq <- function(varCount,
+                    title = "",
+                    weightBy = NULL,
+                    weightByTitleString = NULL,
+                    interactionVar = NULL,
+                    sort.frq = "none",
+                    type = "bars",
+                    geom.size = NULL,
+                    geom.colors = NULL,
+                    axisLabels.x = NULL,
+                    interactionVarLabels = NULL,
+                    axisLimits.x = NULL,
                     axisLimits.y = NULL,
-                    breakTitleAt=50, 
-                    breakLabelsAt=20, 
-                    gridBreaksAt=NULL,
-                    innerBoxPlotWidth=0.15,
-                    innerBoxPlotDotSize=3,
-                    expand.grid=FALSE,
-                    showValueLabels=TRUE,
-                    showCountValues=TRUE,
-                    showPercentageValues=TRUE,
-                    showAxisLabels.x=TRUE,
-                    showAxisLabels.y=TRUE,
-                    showCI=FALSE,
-                    error.bar.color="darkred",
-                    showMeanIntercept=FALSE,
-                    showMeanValue=TRUE,
-                    showStandardDeviation=TRUE,
-                    showNormalCurve=FALSE,
-                    showStandardNormalCurve=FALSE,
-                    adjustNormalCurve.x=FALSE,
-                    meanInterceptLineType=2,
-                    meanInterceptLineSize=0.5,
-                    normalCurveColor="red",
-                    normalCurveSize=0.8,
-                    normalCurveAlpha=0.4,
-                    axisTitle.x=NULL,
-                    axisTitle.y=NULL,
-                    startAxisAt="auto",
-                    hist.skipZeros=FALSE,
-                    autoGroupAt=NULL,
-                    coord.flip=FALSE,
-                    labelPos="outside",
-                    na.rm=TRUE,
-                    printPlot=TRUE) {
+                    breakTitleAt = 50,
+                    breakLabelsAt = 20,
+                    gridBreaksAt = NULL,
+                    innerBoxPlotWidth = 0.15,
+                    innerBoxPlotDotSize = 3,
+                    expand.grid = FALSE,
+                    showValueLabels = TRUE,
+                    showCountValues = TRUE,
+                    showPercentageValues = TRUE,
+                    showAxisLabels.x = TRUE,
+                    showAxisLabels.y = TRUE,
+                    showCI = FALSE,
+                    error.bar.color = "darkred",
+                    showMeanIntercept = FALSE,
+                    showMeanValue = TRUE,
+                    showStandardDeviation = TRUE,
+                    showNormalCurve = FALSE,
+                    showStandardNormalCurve = FALSE,
+                    adjustNormalCurve.x = FALSE,
+                    meanInterceptLineType = 2,
+                    meanInterceptLineSize = 0.5,
+                    normalCurveColor = "red",
+                    normalCurveSize = 0.8,
+                    normalCurveAlpha = 0.4,
+                    axisTitle.x = NULL,
+                    axisTitle.y = NULL,
+                    startAxisAt = "auto",
+                    hist.skipZeros = FALSE,
+                    autoGroupAt = NULL,
+                    coord.flip = FALSE,
+                    labelPos = "outside",
+                    na.rm = TRUE,
+                    printPlot = TRUE) {
   # --------------------------------------------------------
   # try to automatically set labels is not passed as parameter
   # --------------------------------------------------------
@@ -294,7 +262,6 @@ sjp.frq <- function(varCount,
   # remove titles if empty
   # --------------------------------------------------------
   if (!is.null(axisTitle.x) && axisTitle.x == "") axisTitle.x <- NULL
-  if (!is.null(axisTitle.y) && axisTitle.y == "") axisTitle.y <- NULL  
   if (!is.null(title) && title == "") title <- NULL    
   # --------------------------------------------------------
   # check color parameter
@@ -307,23 +274,45 @@ sjp.frq <- function(varCount,
   # --------------------------------------------------------
   # count variable may not be a factor!
   # --------------------------------------------------------
-  if (is.factor(varCount)) varCount <- as.numeric(varCount)
+  if (is.factor(varCount)) varCount <- sjmisc::to_value(varCount)
   # --------------------------------------------------------
-  # We have several options to name the histrogram type
+  # save label values. needed later to determine correct
+  # amount of categories
+  # --------------------------------------------------------
+  labelvalues <- sjmisc::get_values(varCount)
+  # --------------------------------------------------------
+  # We have several options to name the plot type
   # Here we will reduce it to a unique value
   # --------------------------------------------------------
-  if (type == "b" || type == "bar") type <- c("bars")
-  if (type == "dot") type <- c("dots")
-  if (type == "h" || type == "hist") type <- c("histogram")
-  if (type == "d" || type == "density") type <- c("dens")
-  if (type == "l" || type == "lines") type <- c("line")
-  if (type == "box" || type == "boxplot") type <- c("boxplots")
-  if (type == "v") type <- c("violin")
+  if (type == "b" || type == "bar") type <- "bars"
+  if (type == "dot") type <- "dots"
+  if (type == "h" || type == "hist") type <- "histogram"
+  if (type == "d" || type == "density") type <- "dens"
+  if (type == "l" || type == "lines") type <- "line"
+  if (type == "box" || type == "boxplot") type <- "boxplots"
+  if (type == "v" || type == "violins") type <- "violin"
   if (expand.grid == TRUE) {
     expand.grid <- waiver()
   } else {
     expand.grid <- c(0, 0)
   }
+  # --------------------------------------------------------
+  # check default geom.size
+  # --------------------------------------------------------
+  if (is.null(geom.size)) {
+    if (type == "bars") 
+      geom.size <- 0.7
+    else if (type == "dots") 
+      geom.size <- 3
+    else if (type == "hist") 
+      geom.size <- .7
+    else if (type == "line") 
+      geom.size <- .8
+    else if (type == "box") 
+      geom.size <- .3
+    else if (type == "violin") 
+      geom.size <- .3
+  }
   #---------------------------------------------------
   # check whether variable should be auto-grouped
   #---------------------------------------------------
@@ -347,6 +336,11 @@ sjp.frq <- function(varCount,
                                   groupsize = "auto", 
                                   asNumeric = TRUE, 
                                   autoGroupCount = agcnt)
+    # set label attributes
+    varCount <- sjmisc::set_val_labels(varCount, axisLabels.x)
+    # save label values. needed later to determine correct
+    # amount of categories
+    labelvalues <- sjmisc::get_values(varCount)
   }
   # --------------------------------------------------------
   # unlist labels
@@ -358,6 +352,7 @@ sjp.frq <- function(varCount,
   #---------------------------------------------------
   df.frq <- create.frq.df(varCount, 
                           axisLabels.x, 
+                          labelvalues,
                           breakLabelsAt, 
                           sort.frq, 
                           2, 
@@ -368,22 +363,21 @@ sjp.frq <- function(varCount,
   axisLabels.x <- df.frq$labels
   catmin <- df.frq$catmin
   # --------------------------------------------------------
-  # add confidence intervals. first, retrieve conf int
+  # add confidence intervals. first,  check whether 
+  # we have removed NA's. If so, replace NA's, so
+  # we get confidence intervals for CI as well
   # --------------------------------------------------------
-  df.frqci <- sjs.frqci(varCount)$mydat.frq
-  # init variables
-  mydat$lower.ci <- 0
-  mydat$upper.ci <- 0
-  # add conf. to related frequencies
-  for (ici in 1:length(mydat$frq)) {
-    # find frq-pos
-    fpos <- which(df.frqci$frq == mydat$frq[ici])
-    # found anything?
-    if (!is.null(fpos) && length(fpos) > 0) {
-      mydat$lower.ci[ici] <- round(df.frqci$lower.ci[fpos][1])
-      mydat$upper.ci[ici] <- round(df.frqci$upper.ci[fpos][1])
-    }
-  }
+  if (!na.rm) 
+    varCount.ci <- sjmisc::replace_na(varCount, max(varCount, na.rm = T) + 1)
+  else
+    varCount.ci <- varCount
+  # get frequencies with upper/lower CI
+  df.frqci <- sjs.frqci(varCount.ci)$mydat.frq
+  # find matching confidence intervals
+  ci.match <- match(mydat$var, df.frqci$var)
+  # copy ci
+  mydat$lower.ci <- round(df.frqci$lower.ci[ci.match])
+  mydat$upper.ci <- round(df.frqci$upper.ci[ci.match])
   # --------------------------------------------------------
   # Trim labels and title to appropriate size
   # --------------------------------------------------------
@@ -414,7 +408,7 @@ sjp.frq <- function(varCount,
     # If interaction-variable-labels were not defined, simply set numbers from 1 to
     # amount of categories instead
     } else {
-      iavarLabLength <- length(unique(na.omit(interactionVar)))
+      iavarLabLength <- length(unique(stats::na.omit(interactionVar)))
       interactionVarLabels <- c(1:iavarLabLength)
     }
   }
@@ -424,7 +418,7 @@ sjp.frq <- function(varCount,
   if (is.null(weightBy)) {
     mittelwert <- mean(varCount, na.rm = TRUE)
   } else {
-    mittelwert <- weighted.mean(varCount, weightBy, na.rm = TRUE)
+    mittelwert <- stats::weighted.mean(varCount, weightBy, na.rm = TRUE)
   }
   stddev <- sd(varCount, na.rm = TRUE)
   # --------------------------------------------------------
@@ -432,14 +426,14 @@ sjp.frq <- function(varCount,
   # --------------------------------------------------------
   if (type == "boxplots" || type == "violin") {
     if (is.null(interactionVar)) {
-      mydat <- na.omit(data.frame(cbind(grp = 1, 
-                                        frq = varCount, 
-                                        var = varCount)))
+      mydat <- stats::na.omit(data.frame(cbind(grp = 1, 
+                                               frq = varCount, 
+                                               var = varCount)))
     } else {
-      mydat <- na.omit(data.frame(cbind(grp = 1, 
-                                        ia = interactionVar, 
-                                        frq = varCount, 
-                                        var = varCount)))
+      mydat <- stats::na.omit(data.frame(cbind(grp = 1, 
+                                               ia = interactionVar, 
+                                               frq = varCount, 
+                                               var = varCount)))
       mydat$ia <- as.factor(mydat$ia)
     }
     mydat$grp <- as.factor(mydat$grp)
@@ -455,28 +449,20 @@ sjp.frq <- function(varCount,
     lower_lim <- axisLimits.y[1]
     upper_lim <- axisLimits.y[2]
   } else {
-    # in case we have a histrogram, calculate
-    # max. y lim depending on highest value
-    if (type != "bars" && type != "dots") {
-      # if we have boxplots, we have different ranges, so we can adjust
-      # the y axis
-      if (type == "boxplots" || type == "violin") {
-        # use an extra standard-deviation as limits for the y-axis when we have boxplots
-        lower_lim <- min(varCount, na.rm = TRUE) - floor(sd(varCount, na.rm = TRUE))
-        upper_lim <- max(varCount, na.rm = TRUE) + ceiling(sd(varCount, na.rm = TRUE))
-        # make sure that the y-axis is not below zero
-        if (lower_lim < 0) {
-          lower_lim <- 0
-          trimViolin <- TRUE
-        }
-      } else {
-        # ... or the amount of max. answers per category
-        upper_lim <- histYlim(varCount)
+    # if we have boxplots, we have different ranges, so we can adjust
+    # the y axis
+    if (type == "boxplots" || type == "violin") {
+      # use an extra standard-deviation as limits for the y-axis when we have boxplots
+      lower_lim <- min(varCount, na.rm = TRUE) - floor(stats::sd(varCount, na.rm = TRUE))
+      upper_lim <- max(varCount, na.rm = TRUE) + ceiling(stats::sd(varCount, na.rm = TRUE))
+      # make sure that the y-axis is not below zero
+      if (lower_lim < 0) {
+        lower_lim <- 0
+        trimViolin <- TRUE
       }
     } else {
-      # else calculate upper y-axis-range depending
-      # the amount of max. answers per category
-      upper_lim <- freqYlim(mydat$frq)
+      # ... or the amount of max. answers per category
+      upper_lim <- max(pretty(table(varCount)))
     }
   }
   # --------------------------------------------------------
@@ -585,6 +571,10 @@ sjp.frq <- function(varCount,
     histgridbreaks <- c(seq(lower_lim, maxx, by = gridBreaksAt))
   }
   # ----------------------------------
+  # set x-axis limits
+  # ----------------------------------
+  if (is.null(axisLimits.x)) axisLimits.x <- c(catmin, maxx)
+  # ----------------------------------
   # set y scaling and label texts
   # ----------------------------------
   # set Y-axis, depending on the calculated upper y-range.
@@ -607,7 +597,7 @@ sjp.frq <- function(varCount,
   stdmean <- diff(range(varCount, na.rm = TRUE)) / 2
   stdadjust <- min(varCount, na.rm = TRUE)
   stdsd <- stdmean / 4
-  stdlen <- length(na.omit(varCount))
+  stdlen <- length(stats::na.omit(varCount))
   # ----------------------------------
   # Check how many categories we have on the x-axis.
   # If it exceeds the user defined limits, plot
@@ -684,7 +674,7 @@ sjp.frq <- function(varCount,
     # Start density plot here
     # --------------------------------------------------
     } else if (type == "dens") {
-      x <- na.omit(varCount)
+      x <- stats::na.omit(varCount)
       densityDat <- data.frame(x)
       # First, plot histogram with density curve
       baseplot <- ggplot(densityDat, aes(x = x)) +
@@ -694,14 +684,16 @@ sjp.frq <- function(varCount,
                      fill = "cornsilk", 
                      alpha = 0.3) +
         # remove margins from left and right diagram side
-        scale_x_continuous(expand = expand.grid, breaks = histgridbreaks)
+        scale_x_continuous(expand = expand.grid, 
+                           breaks = histgridbreaks,
+                           limits = axisLimits.x)
       # check whether user wants to overlay the histogram
       # with a normal curve
       if (showNormalCurve) {
         baseplot <- baseplot +
           stat_function(fun = dnorm,
                         args = list(mean = mean(densityDat$x),
-                                    sd = sd(densityDat$x)),
+                                    sd = stats::sd(densityDat$x)),
                         colour = normalCurveColor,
                         size = normalCurveSize,
                         alpha = normalCurveAlpha)
@@ -722,7 +714,7 @@ sjp.frq <- function(varCount,
       # -----------------------------------------------------------------
       # base constructor
       if (hist.skipZeros) {
-        x <- na.omit(varCount)
+        x <- stats::na.omit(varCount)
         if (geom.size < round(diff(range(x)) / 50)) message("Using very small binwidth. Consider adjusting \"geom.size\"-parameter.")
         hist.dat <- data.frame(x)
         baseplot <- ggplot(mydat)
@@ -822,7 +814,7 @@ sjp.frq <- function(varCount,
       }
       baseplot <- baseplot +
         # remove margins from left and right diagram side
-        scale_x_continuous(limits = c(catmin, maxx), 
+        scale_x_continuous(limits = axisLimits.x, 
                            expand = expand.grid, 
                            breaks = histgridbreaks) +
         yscale
@@ -843,45 +835,6 @@ sjp.frq <- function(varCount,
 }
 
 
-
-# Berechnet die aufgerundete Obergrenze der y-Achse anhand
-# des höchsten Datenwertes einer Antwortmöglichkeit.
-# Dadurch werden Balkendiagramme eines Datensatzes immer unterschiedlich
-# dargestellt, je nach Anzahl der häufigsten Antworten. Die y-Achse
-# geht immer von 0 bis (maximale Antworthäufigkeit einer Variable)
-#
-# Parameter:
-# - var: die Variable mit den Antwortmöglichkeiten
-freqYlim <- function(var) {
-  # suche die Antwort mit den häufigsten Antworten,
-  # also den höchsten Wert einer Variablenausprägung
-  len <- max(var)
-  
-  anzahl <- 5
-  while (len >= (10 * anzahl)) {
-    anzahl <- anzahl + 5
-  }
-  correct <- 10 + (floor(log10(len)) - 1)
-  return(correct * anzahl)  
-}
-
-histYlim <- function(var) {
-  # suche die Antwort mit den häufigsten Antworten,
-  # also den höchsten Wert einer Variablenausprägung
-  len <- max(table(var))
-  
-  if (len < 100) {
-    anzahl <- 10
-  } else {
-    anzahl <- 100
-  }
-  
-  li <- ceiling(len/anzahl)
-  if ((li %% 2) == 1) li <- li + 1
-
-  return(li * anzahl)
-}
-
 # usage:
 # df<-insertRowToDF(df,5,c(16,0)); # inserting the values (16,0) after the 5th row
 insertRowToDF <- function(X, index_after, vector_to_insert){
