@@ -1,83 +1,19 @@
 # bind global variables
-if(getRversion() >= "2.15.1") utils::globalVariables(c("OR", "lower", "upper", "p", "pa", "shape"))
+utils::globalVariables(c("OR", "lower", "upper", "p", "pa", "shape"))
 
 #' @title Plot odds ratios (forest plots) of multiple fitted glm's
 #' @name sjp.glmm
 #' 
 #' @description Plot odds ratios (forest plots) of multiple fitted glm's with confidence intervalls in one plot.
 #' 
-#' @param ... One or more fitted glm-objects. May also be a \code{\link{list}}-object with 
-#'          fitted models, instead of separating each model with comma. See examples.
-#' @param title Diagram's title as string.
-#'          Example: \code{title = "my title"}
-#' @param labelDependentVariables Labels of the dependent variables of all fitted models
-#'          which have been used as first parameter(s), provided as char vector.
-#' @param legendDepVarTitle A character vector used for the title of the dependent variable's legend.
-#'          Default is \code{"Dependent Variables"}.
-#' @param legendPValTitle A character vector used for the title of the significance level's legend.
-#'          Default is \code{"p-level"}. Only applies if \code{usePShapes} is \code{TRUE}.
-#' @param stringModel String constant used as legend text for the model names in case no 
-#'          labels for the dependent variables are provided (see \code{labelDependentVariables}).
-#'          Default is \code{"Model"}.
-#' @param axisLabels.y Labels of the predictor variables (independent vars, odds) that are used for labelling the
-#'          axis. Passed as vector of strings.
-#'          Example: \code{axisLabels.y = c("Label1", "Label2", "Label3")} \cr
-#'          \strong{Note:} If you use the \code{\link[sjmisc]{read_spss}} function and the \code{\link[sjmisc]{get_val_labels}} function, you receive a
-#'          \code{list} object with label strings. The labels may also be passed as list object. They will be coerced
-#'          to character vector automatically.
-#' @param showAxisLabels.y Whether odds names (predictor labels) should be shown or not.
-#' @param axisTitle.x A label ("title") for the x axis.
-#' @param axisLimits Defines the range of the axis where the beta coefficients and their confidence intervalls
-#'          are drawn. By default, the limits range from the lowest confidence interval to the highest one, so
-#'          the diagram has maximum zoom. Use your own values as 2-value-vector, for instance: \code{limits = c(-0.8, 0.8)}.
-#' @param breakTitleAt Wordwrap for diagram title. Determines how many chars of the title are displayed in
-#'          one line and when a line break is inserted into the title
-#' @param breakLabelsAt Wordwrap for diagram labels. Determines how many chars of the category labels are displayed in 
-#'          one line and when a line break is inserted
-#' @param breakLegendAt Wordwrap for legend, i.e. names of the dependent variables of each fitted model.
-#'          See parameter \code{labelDependentVariables}. Determines how many chars of each dependent variable name
-#'          is displayed in one line in the legend and when a line break is inserted
-#' @param gridBreaksAt Sets the breaks on the y axis, i.e. at every n'th position a major
-#'          grid is being printed. Default is 0.5
-#' @param transformTicks if \code{TRUE}, the grid bars have exponential distances, i.e. they
-#'          visually have the same distance from one grid bar to the next. Default is \code{FALSE} which
-#'          means that grids are plotted on every \code{gridBreaksAt}'s position, thus the grid bars
-#'          become narrower with higher odds ratio values.
-#' @param geom.size The size of the points that indicate the odds ratios. Default is 3.
-#' @param geom.spacing Defines the space between the dots and error bars of the plotted fitted models. Default
-#'          is 0.3.
-#' @param geom.colors A vector with colors for representing the odds ratio values (i.e. points and error bars)
-#'          of the different fitted models. Thus, the length of this vector must be equal to
-#'          the length of supplied fitted models, so each model is represented by its own color.
-#'          You can use:
-#'          \itemize{
-#'            \item If not specified, the qualitative \code{"Dark2"} color brewer palette will be used.
-#'            \item If \code{"gs"}, a greyscale will be used.
-#'            \item If \code{geom.colors} is any valid color brewer palette name, the related \href{http://colorbrewer2.org}{color brewer} palette will be used. Use \code{display.brewer.all()} from the \code{RColorBrewer} package to view all available palette names.
-#'            \item Else specify your own color values as vector (e.g. \code{geom.colors = c("#f00000", "#00ff00", "#0080ff")}).
-#'            }
-#' @param fade.ns if \code{TRUE}, non significant estimates will be printed in slightly faded colors.
-#' @param usePShapes If \code{TRUE}, significant levels are distinguished by different point shapes and a related
-#'          legend is plotted. Default is \code{FALSE}.
-#' @param interceptLineType The linetype of the intercept line (zero point). Default is \code{2} (dashed line).
-#' @param interceptLineColor The color of the intercept line. Default value is \code{"grey70"}.
-#' @param hideLegend Indicates whether legend (guide) should be shown or not.
-#' @param coord.flip If \code{TRUE} (default), predictors are plotted on the left y-axis and estimate
-#'          values are plotted on the x-axis.
-#' @param showIntercept If \code{TRUE}, the intercept of the fitted model is also plotted.
-#'          Default is \code{FALSE}. Please note that due to exp-transformation of
-#'          estimates, the intercept in some cases can not be calculated, thus the
-#'          function call is interrupted and no plot printed.
-#' @param showValueLabels Whether the beta and standardized beta values should be plotted 
-#'          to each dot or not.
-#' @param labelDigits The amount of digits for rounding the estimations (see \code{showValueLabels}).
-#'          Default is 2, i.e. estimators have 2 digits after decimal point.
-#' @param showPValueLabels Whether the significance levels of each coefficient should be appended
-#'          to values or not.
-#' @param facet.grid \code{TRUE} when each model should be plotted as single facet instead of 
-#'          an integrated single graph.
-#' @param printPlot If \code{TRUE} (default), plots the results as graph. Use \code{FALSE} if you don't
-#'          want to plot any graphs. In either case, the ggplot-object will be returned as value.
+#' @param ... one or more fitted glm-objects. May also be a \code{\link{list}}-object with 
+#'          fitted models, instead of separating each model with comma. See 'Examples'.
+#'          
+#' @inheritParams sjp.lmm
+#' @inheritParams sjp.glm
+#' @inheritParams sjp.lm
+#' @inheritParams sjp.grpfrq
+#'          
 #' @return (Insisibily) returns the ggplot-object with the complete plot (\code{plot}) as well as the data frame that
 #'           was used for setting up the ggplot-object (\code{df}).
 #'          
@@ -118,37 +54,38 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("OR", "lower", "upper", "
 #' 
 #' @import ggplot2
 #' @import sjmisc
+#' @importFrom stats na.omit
 #' @export
-sjp.glmm <- function(..., 
-                    title=NULL,
-                    labelDependentVariables=NULL, 
-                    legendDepVarTitle="Dependent Variables",
-                    legendPValTitle="p-level",
-                    stringModel="Model",
-                    axisLabels.y=NULL, 
-                    axisTitle.x="Odds Ratios",
-                    axisLimits=NULL,
-                    breakTitleAt=50, 
-                    breakLabelsAt=25,
-                    breakLegendAt=20,
-                    gridBreaksAt=0.5,
-                    transformTicks=TRUE,
-                    geom.size=3,
-                    geom.spacing=0.4,
-                    geom.colors="Set1",
-                    fade.ns=TRUE,
-                    usePShapes=FALSE,
-                    interceptLineType=2,
-                    interceptLineColor="grey70",
-                    coord.flip=TRUE,
-                    showIntercept=FALSE,
-                    showAxisLabels.y=TRUE,
-                    showValueLabels=TRUE, 
-                    labelDigits=2,
-                    showPValueLabels=TRUE,
-                    hideLegend=FALSE,
-                    facet.grid=FALSE,
-                    printPlot=TRUE) {
+sjp.glmm <- function(...,
+                     title = NULL,
+                     labelDependentVariables = NULL,
+                     legendDepVarTitle = "Dependent Variables",
+                     legendPValTitle = "p-level",
+                     stringModel = "Model",
+                     axisLabels.y = NULL,
+                     axisTitle.x = "Odds Ratios",
+                     axisLimits = NULL,
+                     breakTitleAt = 50,
+                     breakLabelsAt = 25,
+                     breakLegendTitleAt = 20,
+                     gridBreaksAt = 0.5,
+                     transformTicks = TRUE,
+                     geom.size = 3,
+                     geom.spacing = 0.4,
+                     geom.colors = "Set1",
+                     fade.ns = TRUE,
+                     usePShapes = FALSE,
+                     interceptLineType = 2,
+                     interceptLineColor = "grey70",
+                     coord.flip = TRUE,
+                     showIntercept = FALSE,
+                     showAxisLabels.y = TRUE,
+                     showValueLabels = TRUE,
+                     labelDigits = 2,
+                     showPValueLabels = TRUE,
+                     hideLegend = FALSE,
+                     facet.grid = FALSE,
+                     printPlot = TRUE) {
   # --------------------------------------------------------
   # retrieve list of fitted models
   # --------------------------------------------------------
@@ -184,7 +121,7 @@ sjp.glmm <- function(...,
   if (!is.null(axisTitle.x)) axisTitle.x <- sjmisc::word_wrap(axisTitle.x, breakTitleAt)
   # check length of dependent variables
   if (!is.null(labelDependentVariables)) {
-    labelDependentVariables <- sjmisc::word_wrap(labelDependentVariables, breakLegendAt)
+    labelDependentVariables <- sjmisc::word_wrap(labelDependentVariables, breakLegendTitleAt)
   } else {
     # else if we have no labels of dependent variables supplied, use a 
     # default string (Model) for legend
@@ -298,7 +235,7 @@ sjp.glmm <- function(...,
     upper_lim <- ceiling(10 * max(finalodds$upper)) / 10
     lower_lim <- floor(10 * min(finalodds$lower)) / 10
     # avoid zero or NA axis limit!
-    if (is.na(upper_lim)) upper_lim <- ceiling(10 * max(na.omit(finalodds$upper))) / 10
+    if (is.na(upper_lim)) upper_lim <- ceiling(10 * max(stats::na.omit(finalodds$upper))) / 10
     if (lower_lim == 0 || is.na(lower_lim)) lower_lim <- 0.01
     # if we show p value labels, increase upper
     # limit of x axis, so labels are plotted inside
@@ -365,7 +302,8 @@ sjp.glmm <- function(...,
     # print value labels and p-values
     geom_text(aes(label = p, y = upper), 
               position = position_dodge(width = -geom.spacing), 
-              hjust = -0.1) +
+              hjust = -0.1,
+              show_guide = FALSE) +
     # Intercept-line
     geom_hline(yintercept = 1, 
                linetype = interceptLineType, 
@@ -403,7 +341,7 @@ sjp.glmm <- function(...,
   # flip coordinates?
   # --------------------------------------------------------
   if (coord.flip)  plotHeader <- plotHeader + coord_flip()
-  if (facet.grid) plotHeader <- plotHeader + facet_grid(. ~ grp)
+  if (facet.grid) plotHeader <- plotHeader + facet_grid(~grp)
   # ---------------------------------------------------------
   # set geom colors
   # ---------------------------------------------------------
@@ -419,7 +357,7 @@ sjp.glmm <- function(...,
   # -------------------------------------
   # return results
   # -------------------------------------
-  invisible (structure(class = "sjpglmm",
-                       list(plot = plotHeader,
-                            df = finalodds)))
+  invisible(structure(class = "sjpglmm",
+                      list(plot = plotHeader,
+                           df = finalodds)))
 }
