@@ -7,69 +7,65 @@
 #'
 #' @seealso \href{http://www.strengejacke.de/sjPlot/sjp.scatter}{sjPlot manual: sjp.scatter}
 #'              
-#' @param x A vector (variable) indicating the x positions. If not specified (i.e. if
+#' @param x vector indicating the x positions. If not specified (i.e. if
 #'          \code{NULL}), a range from 1 to length of \code{y} is used to spread the
 #'          dots along the x axis.
-#' @param y A vector (variable) indicating the y positions. If not specified (i.e. if
+#' @param y vector indicating the y positions. If not specified (i.e. if
 #'          \code{NULL}), a range from 1 to length of \code{x} is used to spread the
 #'          dots along the y axis.
-#' @param grp A grouping variable. If not \code{NULL}, the scatter plot will be grouped. See
-#'          examples below. Default is \code{NULL}, i.e. not grouping is done.
-#' @param title Title of the diagram, plotted above the whole diagram panel.
+#' @param grp grouping variable. If not \code{NULL}, the scatter plot will be grouped. See
+#'          'Examples'. Default is \code{NULL}, i.e. not grouping is done.
+#' @param pointLabels character vector with names for each coordinate pair given
+#'          by \code{x} and \code{y}, so instead of dots, text labels are
+#'          printed to the plot. Must be of same length as \code{x} and \code{y}.
+#'          If \code{pointLabels} has a different length, data points will be trimmed
+#'          to match \code{pointLabels}. If \code{pointLabels = NULL} (default),
+#'          dots instead of labels are printed.
+#' @param axisTitle.x title for the x axis. Use \code{NULL} to automatically 
+#'          detect variable names that will be used as title
+#'          (see \code{\link[sjmisc]{set_var_labels}}) for details).
+#' @param axisTitle.y title for the y axis.
 #'          Use \code{NULL} to automatically detect variable names that will be used as title
 #'          (see \code{\link[sjmisc]{set_var_labels}}) for details).
-#' @param legendTitle Title of the diagram's legend.
-#' @param legendLabels Labels for the guide/legend.
-#' @param axisTitle.x A label (title) for the x axis.
-#'          Use \code{NULL} to automatically detect variable names that will be used as title
-#'          (see \code{\link[sjmisc]{set_var_labels}}) for details).
-#' @param axisTitle.y A label (title) for the y axis.
-#'          Use \code{NULL} to automatically detect variable names that will be used as title
-#'          (see \code{\link[sjmisc]{set_var_labels}}) for details).
-#' @param breakTitleAt Wordwrap for diagram title. Determines how many chars of the title are displayed in
-#'          one line and when a line break is inserted into the title.
-#' @param breakLegendTitleAt Wordwrap for diagram legend title. Determines how many chars of the legend's title 
-#'          are displayed in one line and when a line break is inserted.
-#' @param breakLegendLabelsAt Wordwrap for diagram legend labels. Determines how many chars of the legend labels are 
-#'          displayed in one line and when a line break is inserted.
-#' @param geom.size The size of scattered points.
-#' @param geom.colors The color(s) of scattered points. If \code{grp} is not \code{NULL}, groups are indicated
-#'          by different colors, thus a vector with multiple color values has to be supplied. By default,
-#'          the \code{Set1} palette of diverging palette type is chosen (see \url{http://colorbrewer2.org}).
-#' @param showTickMarkLabels.x Whether x axis tick mark labels should be shown or not.
-#' @param showTickMarkLabels.y Whether y axis tick mark labels  should be shown or not.
-#' @param showGroupFitLine If \code{TRUE}, a fitted line for each group is drawn. See \code{fitmethod} to change the
-#'          fit method of the fitted lines.
-#' @param showTotalFitLine If \code{TRUE}, a fitted line for the overall scatterplot is drawn. See \code{fitmethod} to change the
-#'          fit method of the fitted line.
-#' @param showSE If \code{TRUE}, a shaded region indicating the standard error of the fitted lines will be added.
-#' @param fitmethod By default, a linear method (\code{"lm"}) is used for fitting the fit lines. Possible values are
-#'          for instance:
-#'          \itemize{
-#'            \item \code{"lm"}
-#'            \item \code{"glm"}
-#'            \item \code{"loess"}
-#'            \item \code{"auto"}
-#'          }
-#'          (see \href{http://docs.ggplot2.org/current/stat_smooth.html}{ggplot-docs} for more details).
-#' @param useJitter If \code{TRUE}, points will be jittered (to avoid overplotting).
-#' @param autojitter If \code{TRUE}, points will be jittered according to an overlap-estimation. A matrix of \code{x}
-#'          and \code{y} values is created and the amount of cells (indicating a unique point position) is calculated.
-#'          If more than 15\% (see \code{jitterRatio}) of the approximated amount of unique point coordinates seem to
+#' @param geom.size size of point geoms.
+#' @param geom.colors color(s) of point geoms. If \code{grp} is not \code{NULL}, 
+#'          groups are indicated by different colors, thus a vector with multiple
+#'          color values has to be supplied.
+#' @param showTickMarkLabels.x logica, whether x axis tick mark labels should be shown or not.
+#' @param showTickMarkLabels.y logical, hether y axis tick mark labels  should be shown or not.
+#' @param showGroupFitLine logical, if \code{TRUE}, a fitted line for each group 
+#'          is drawn. See \code{fitmethod} to change the fit method of the fitted lines.
+#' @param showTotalFitLine logical, if \code{TRUE}, a fitted line for the overall 
+#'          scatterplot is drawn. See \code{fitmethod} to change the fit method 
+#'          of the fitted line.
+#' @param show.se logical, if \code{TRUE}, a shaded region indicating the standard error of the fitted lines will be added.
+#' @param fitmethod By default, a linear method (\code{"lm"}) is used for fitting 
+#'          the fit lines. Possible values are for instance \code{"lm"}, \code{"glm"},
+#'          \code{"loess"} or \code{"auto"}
+#'          (see \href{http://docs.ggplot2.org/current/stat_smooth.html}{ggplot-docs} 
+#'          for more details).
+#' @param useJitter logical, if \code{TRUE}, points will be jittered (to avoid overplotting).
+#' @param autojitter logical, if \code{TRUE}, points will be jittered according 
+#'          to an overlap-estimation. A matrix of \code{x} and \code{y} values 
+#'          is created and the amount of cells (indicating a unique point position) 
+#'          is calculated. If more than 15\% (see \code{jitterRatio}) of the 
+#'          approximated amount of unique point coordinates seem to
 #'          overlap, they are automatically jittered.
-#' @param jitterRatio The ratio of tolerated overlapping (see \code{autojitter}). If approximated amount of overlapping 
-#'          points exceed this ration, they are automatically jittered. Default is 0.15. Valid values range between 0 and 1.
-#' @param showRug If \code{TRUE}, a marginal rug plot is displayed in the graph (see \href{http://docs.ggplot2.org/current/geom_rug.html}{ggplot-docs}
-#'          for more details).)
-#' @param hideLegend Indicates whether legend (guide) should be shown or not.
+#' @param jitterRatio ratio of tolerated overlapping (see \code{autojitter}). 
+#'          If approximated amount of overlapping  points exceed this ratio,
+#'          they are automatically jittered. Default is 0.15. Valid values range
+#'          between 0 and 1.
+#' @param showRug logical, if \code{TRUE}, a marginal rug plot is displayed
+#'          in the graph (see \href{http://docs.ggplot2.org/current/geom_rug.html}{ggplot-docs}
+#'          for more details).
 #' @param facet.grid \code{TRUE} when each scatter plot group should be plotted as single facet instead of 
 #'          an integrated single graph. Only applies if \code{grp} is not \code{NULL}. Each category of
 #'          \code{grp} will be plotted in an own facet.
-#' @param printPlot If \code{TRUE} (default), plots the results as graph. Use \code{FALSE} if you don't
-#'          want to plot any graphs. In either case, the ggplot-object will be returned as value.
 #' @return (Insisibily) returns the ggplot-object with the complete plot (\code{plot}) as well as the data frame that
 #'           was used for setting up the ggplot-object (\code{df}).
 #'
+#' @inheritParams sjp.grpfrq
+#'
 #' @examples
 #' # load sample date
 #' library(sjmisc)
@@ -101,7 +97,7 @@
 #' sjp.scatter(efc$c160age,efc$e17age, efc$e42dep,
 #'             showGroupFitLine = TRUE, 
 #'             facet.grid = TRUE, 
-#'             showSE = TRUE)
+#'             show.se = TRUE)
 #' 
 #' # plot residuals of fitted models
 #' fit <- lm(neg_c_7 ~ quol_5, data = efc)
@@ -111,36 +107,44 @@
 #' sjp.scatter(efc$c160age, efc$e17age, efc$e42dep,
 #'             title = "", axisTitle.x = "", axisTitle.y = "")
 #' 
+#' # plot text labels
+#' pl <- c(1:10)
+#' for (i in 1:10) pl[i] <- paste(sample(c(0:9, letters, LETTERS), 
+#'                                       8, replace = TRUE), 
+#'                                collapse = "")
+#' sjp.scatter(runif(10), runif(10), pointLabels = pl)
 #'   
 #' @importFrom scales brewer_pal
+#' @importFrom stats na.omit
 #' @import ggplot2
 #' @export
-sjp.scatter <- function(x=NULL,
-                        y=NULL,
-                        grp=NULL,
-                        title="", 
-                        legendTitle=NULL,
-                        legendLabels=NULL,
-                        axisTitle.x=NULL,
-                        axisTitle.y=NULL,
-                        breakTitleAt=50, 
-                        breakLegendTitleAt=20, 
-                        breakLegendLabelsAt=20,
-                        geom.size=3,
-                        geom.colors=NULL,
-                        showTickMarkLabels.x=TRUE,
-                        showTickMarkLabels.y=TRUE,
-                        showGroupFitLine=FALSE,
-                        showTotalFitLine=FALSE,
-                        showSE=FALSE,
-                        fitmethod="lm",
-                        useJitter=FALSE,
-                        autojitter=TRUE,
-                        jitterRatio=0.15,
-                        showRug=FALSE,
-                        hideLegend=FALSE,
-                        facet.grid=FALSE,
-                        printPlot=TRUE) {
+sjp.scatter <- function(x = NULL,
+                        y = NULL,
+                        grp = NULL,
+                        title = "",
+                        legendTitle = NULL,
+                        legendLabels = NULL,
+                        pointLabels = NULL,
+                        axisTitle.x = NULL,
+                        axisTitle.y = NULL,
+                        breakTitleAt = 50,
+                        breakLegendTitleAt = 20,
+                        breakLegendLabelsAt = 20,
+                        geom.size = 3,
+                        geom.colors = NULL,
+                        showTickMarkLabels.x = TRUE,
+                        showTickMarkLabels.y = TRUE,
+                        showGroupFitLine = FALSE,
+                        showTotalFitLine = FALSE,
+                        show.se = FALSE,
+                        fitmethod = "lm",
+                        useJitter = FALSE,
+                        autojitter = TRUE,
+                        jitterRatio = 0.15,
+                        showRug = FALSE,
+                        hideLegend = FALSE,
+                        facet.grid = FALSE,
+                        printPlot = TRUE) {
   # --------------------------------------------------------
   # check parameters
   # --------------------------------------------------------
@@ -209,9 +213,26 @@ sjp.scatter <- function(x=NULL,
     hideLegend <- TRUE
   }
   # simple data frame
-  df <- na.omit(data.frame(cbind(x = x, y = y, grp = grp)))
+  df <- stats::na.omit(data.frame(cbind(x = x, y = y, grp = grp)))
   # group as factor
   df$grp <- as.factor(df$grp)
+  # do we have point labels?
+  if (!is.null(pointLabels)) {
+    # check length
+    if (length(pointLabels) > nrow(df)) {
+      # Tell user that we have too many point labels
+      warning("More point labels than data points. Omitting remaining point labels", call. = F)
+      # shorten vector
+      pointLabels <- pointLabels[1:nrow(df)]
+    } else if (length(pointLabels) < nrow(df)) {
+      # Tell user that we have too less point labels
+      warning("Less point labels than data points. Omitting remaining data point", call. = F)
+      # shorten data frame
+      df <- df[1:length(pointLabels), ]
+    }
+    # append labels
+    df$pointLabels <- as.character(pointLabels)
+  }
   # --------------------------------------------------------
   # Prepare and trim legend labels to appropriate size
   # --------------------------------------------------------
@@ -250,9 +271,22 @@ sjp.scatter <- function(x=NULL,
   # Use Jitter/Points
   # --------------------------------------------------------
   if (useJitter) {
-    scatter <- scatter + geom_jitter(size = geom.size)
+    # do we have text?
+    if (!is.null(pointLabels))
+      scatter <- scatter + geom_text(aes(label = pointLabels), 
+                                     size = geom.size,
+                                     position = "jitter")
+    else
+      # else plot dots
+      scatter <- scatter + geom_jitter(size = geom.size)
   } else {
-    scatter <- scatter + geom_point(size = geom.size)
+    # do we have text?
+    if (!is.null(pointLabels))
+      scatter <- scatter + geom_text(aes(label = pointLabels), 
+                                     size = geom.size)
+    else
+      # else plot dots
+      scatter <- scatter + geom_point(size = geom.size)
   }
   # --------------------------------------------------------
   # Show fitted lines
@@ -260,9 +294,9 @@ sjp.scatter <- function(x=NULL,
   if (showGroupFitLine) scatter <- scatter + stat_smooth(data = df, 
                                                          aes(colour = grp), 
                                                          method = fitmethod, 
-                                                         se = showSE)
+                                                         se = show.se)
   if (showTotalFitLine) scatter <- scatter + stat_smooth(method = fitmethod, 
-                                                         se = showSE, 
+                                                         se = show.se, 
                                                          colour = "black")
   # --------------------------------------------------------
   # set font size for axes.
@@ -307,8 +341,8 @@ sjp.scatter <- function(x=NULL,
   # -------------------------------------
   # return results
   # -------------------------------------
-  invisible (structure(class = "sjpscatter",
-                       list(plot = scatter,
-                            df = df)))
+  invisible(structure(class = "sjpscatter",
+                      list(plot = scatter,
+                           df = df)))
 }
                        
\ No newline at end of file
