@@ -3,90 +3,7 @@
 #' 
 #' @description Set global theme options for sjp-functions.
 #' 
-#' @param title.size Size of the plot title. Default is 1.3.
-#' @param title.color Color of the plot title. Default is \code{"black"}.
-#' @param title.align Alignment of plot title. Must be one of \code{"left"} (default),
-#'          \code{"center"} or \code{"right"}. You may use initial letter only.
-#' @param geom.outline.size Size of the bar outlines. Default is 0.1. Use
-#'          size of \code{0} to remove geom outline.
-#' @param geom.outline.color Color of geom outline. Only applies, if \code{geom.outline.size}
-#'          is larger than 0.
-#' @param geom.boxoutline.size Size of outlines and median bar especially for boxplots.
-#'          Default is 0.5. Use size of \code{0} to remove boxplot outline.
-#' @param geom.boxoutline.color Color of outlines and median bar especially for boxplots.
-#'          Only applies, if \code{geom.boxoutline.size} is larger than 0.
-#' @param geom.alpha Specify the transparancy (alpha value) of geoms
-#' @param geom.linetype Linetype of line geoms. Default is \code{1} (solid line).
-#' @param geom.errorbar.size Size (thickness) of error bars. Default is \code{0.8}
-#' @param geom.errorbar.linetype Linetype of error bars. Default is \code{1} (solid line).
-#' @param geom.label.color Color of geom's value and annotation labels.
-#' @param geom.label.size Size of geom's value and annotation labels.
-#' @param geom.label.alpha Alpha level of geom's value and annotation labels.
-#' @param geom.label.angle Angle of geom's value and annotation labels.
-#' @param axis.title.color Color of x- and y-axis title labels.
-#' @param axis.title.size Size of x- and y-axis title labels.
-#' @param axis.angle.x Angle for x-axis labels.
-#' @param axis.angle.y Angle for y-axis labels.
-#' @param axis.angle Angle for x- and y-axis labels. If set, overrides both \code{axis.angle.x} and \code{axis.angle.y}
-#' @param axis.textcolor.x Color for x-axis labels. If not specified, a default dark gray
-#'          color palette will be used for the labels.
-#' @param axis.textcolor.y Color for y-axis labels. If not specified, a default dark gray
-#'          color palette will be used for the labels.
-#' @param axis.textcolor Color for both x- and y-axis labels. 
-#'          If set, overrides both \code{axis.textcolor.x} and \code{axis.textcolor.y}
-#' @param axis.linecolor.x color of x-axis border.
-#' @param axis.linecolor.y color of y-axis border.
-#' @param axis.linecolor Color for both x- and y-axis borders. 
-#'          If set, overrides both \code{axis.linecolor.x} and \code{axis.linecolor.y}.
-#' @param axis.line.size Size (thickness) of axis lines. Only affected, if \code{axis.linecolor}
-#'          is set.
-#' @param axis.textsize.x Size of x-axis labels.
-#' @param axis.textsize.y Size of y-axis labels.
-#' @param axis.textsize Size for both x- and y-axis labels. 
-#'          If set, overrides both \code{axis.textsize.x} and \code{axis.textsize.y}.
-#' @param axis.tickslen Length of axis tick marks
-#' @param axis.ticksol Color of axis tick marks.
-#' @param axis.ticksmar Margin between axis labels and tick marks.
-#' @param panel.bordercol Color of whole diagram border (panel border).
-#' @param panel.backcol Color of the diagram's background.
-#' @param panel.col Color of both diagram's border and background.
-#'          If set, overrides both \code{panel.bordercol} and \code{panel.backcol}.
-#' @param panel.major.gridcol Color of the major grid lines of the diagram background.
-#' @param panel.minor.gridcol Color of the minor grid lines of the diagram background.
-#' @param panel.gridcol Color for both minor and major grid lines of the diagram background.
-#'          If set, overrides both \code{panel.major.gridcol} and \code{panel.minor.gridcol}.
-#' @param panel.major.linetype Line type for major grid lines.
-#' @param panel.minor.linetype Line type for minor grid lines.
-#' @param plot.backcol Color of the plot's background.
-#' @param plot.bordercol Color of whole plot's border (panel border).
-#' @param plot.col Color of both plot's region border and background.
-#'          If set, overrides both \code{plot.backcol} and \code{plot.bordercol}.
-#' @param legend.pos Position of the legend, if a legend is drawn.\cr
-#'          \emph{legend outside plot} \cr
-#'          Use \code{"bottom"}, \code{"top"}, \code{"left"}
-#'          or \code{"right"} to position the legend above, below, on the left or right side of the diagram. 
-#'          Right positioning is default. \cr
-#'          \emph{legend inside plot} \cr
-#'          If \code{legend.inside} is \code{TRUE}, legend can be placed inside
-#'          plot. Use \code{"top left"}, \code{"top right"}, \code{"bottom left"} and \code{"bottom right"}
-#'          to position legend in any of these corners, or a two-element numeric vector with values from 0-1. \cr
-#'          See also \code{legend.inside}.
-#' @param legend.just Justification of legend, relative to its position ("center" or 
-#'          two-element numeric vector with values from 0-1. By default (outside legend),
-#'          justification is centered. If legend is inside and justification not specified,
-#'          legend justification is set according to legend position.
-#' @param legend.inside Logical, use \code{TRUE} to put legend inside the plotting area. See \code{legend.pos}.
-#' @param legend.size Text size of the legend. Default is 1. Relative size, so recommended values are from 0.3 to
-#'          2.5
-#' @param legend.color Color of the legend labels.
-#' @param legend.title.size Text size of the legend title.
-#' @param legend.title.color Color of the legend title.
-#' @param legend.title.face Font face of the legend title. By default, \code{"bold"} face is used.
-#' @param legend.bordercol Color of the legend's border. Default is \code{"white"}, so no visible border is drawn.
-#' @param legend.backgroundcol Fill color of the legend's background. Default is \code{"white"}, so no visible background is drawn.
-#' @param legend.item.bordercol Color of the legend's item-border. Default is \code{"white"}.
-#' @param legend.item.backcol Fill color of the legend's item-background. Default is \code{"grey90"}.
-#' @param theme Specify pre-set themes (see 'Details'). Valid parameter for ggplot default-themes are:
+#' @param theme specify pre-set themes (see 'Details'). Valid parameter for ggplot default-themes are for instance:
 #'        \itemize{
 #'          \item \code{theme_bw}
 #'          \item \code{theme_classic}
@@ -96,26 +13,113 @@
 #'          \item \code{theme_minimal}
 #'        }
 #'        Furthermore, there are some theme-presets, which can be used:
-#'        \itemize{
-#'          \item \code{"blank"}: a theme with no grids and axes.
-#'          \item \code{"forest"}: a theme for forest plots, with no grids.
-#'          \item \code{"forestgrey"}: a theme for forest plots, with no grids, in "539" style.
-#'          \item \code{"538"}: a grey-scaled theme inspired by \href{http://fivethirtyeight.com}{538-charts}, adapted from \href{http://minimaxir.com/2015/02/ggplot-tutorial/}{minimaxir.com}.
-#'          \item \code{"539"}: a slight modification of the 538-theme.
-#'          \item \code{"scatter"}: a theme for scatter plots in 539-theme-style.
-#'          \item \code{"538w"}, \code{"539w"} and \code{"scatterw"} for themes as described above, however all with white backgrounds.
-#'          \item \code{"blues"}: a blue-colored scheme based on the Blues color-brewer-palette.
-#'          \item \code{"greens"}: a green-colored scheme.
+#'        \describe{
+#'          \item{\code{"blank"}}{a theme with no grids and axes.}
+#'          \item{\code{"forest"}}{a theme for forest plots, with no grids.}
+#'          \item{\code{"forestgrey"}}{a theme for forest plots, with no grids, in "539" style.}
+#'          \item{\code{"538"}}{a grey-scaled theme inspired by \href{http://fivethirtyeight.com}{538-charts}, adapted from \href{http://minimaxir.com/2015/02/ggplot-tutorial/}{minimaxir.com}.}
+#'          \item{\code{"539"}}{a slight modification of the 538-theme.}
+#'          \item{\code{"scatter"}}{a theme for scatter plots in 539-theme-style.}
+#'          \item{\code{"538w"}, \code{"539w"}, \code{"scatterw"} and \code{"forestw"}}{for themes as described above, however all with white backgrounds.}
+#'          \item{\code{"blues"}}{a blue-colored scheme based on the Blues color-brewer-palette.}
+#'          \item{\code{"greens"}}{a green-colored scheme.}
 #'        }
-#' @param base Base theme where theme is built on. By default, all 
-#'          metrics from \code{theme_gray()} are used. See 'Details'
+#' @param title.size size of plot title. Default is 1.3.
+#' @param title.color color of plot title. Default is \code{"black"}.
+#' @param title.align alignment of plot title. Must be one of \code{"left"} (default),
+#'          \code{"center"} or \code{"right"}. You may use initial letter only.
+#' @param geom.outline.size size of bar outlines. Default is 0.1. Use
+#'          size of \code{0} to remove geom outline.
+#' @param geom.outline.color color of geom outline. Only applies, if \code{geom.outline.size}
+#'          is larger than 0.
+#' @param geom.boxoutline.size size of outlines and median bar especially for boxplots.
+#'          Default is 0.5. Use size of \code{0} to remove boxplot outline.
+#' @param geom.boxoutline.color color of outlines and median bar especially for boxplots.
+#'          Only applies, if \code{geom.boxoutline.size} is larger than 0.
+#' @param geom.alpha specifies the transparancy (alpha value) of geoms
+#' @param geom.linetype linetype of line geoms. Default is \code{1} (solid line).
+#' @param geom.errorbar.size size (thickness) of error bars. Default is \code{0.8}
+#' @param geom.errorbar.linetype linetype of error bars. Default is \code{1} (solid line).
+#' @param geom.label.color color of geom's value and annotation labels
+#' @param geom.label.size size of geom's value and annotation labels
+#' @param geom.label.alpha alpha level of geom's value and annotation labels
+#' @param geom.label.angle angle of geom's value and annotation labels
+#' @param axis.title.color color of x- and y-axis title labels
+#' @param axis.title.size size of x- and y-axis title labels
+#' @param axis.angle.x angle for x-axis labels
+#' @param axis.angle.y angle for y-axis labels
+#' @param axis.angle angle for x- and y-axis labels. If set, overrides both \code{axis.angle.x} and \code{axis.angle.y}
+#' @param axis.textcolor.x color for x-axis labels. If not specified, a default dark gray
+#'          color palette will be used for the labels.
+#' @param axis.textcolor.y color for y-axis labels. If not specified, a default dark gray
+#'          color palette will be used for the labels.
+#' @param axis.textcolor color for both x- and y-axis labels. 
+#'          If set, overrides both \code{axis.textcolor.x} and \code{axis.textcolor.y}
+#' @param axis.linecolor.x color of x-axis border
+#' @param axis.linecolor.y color of y-axis border
+#' @param axis.linecolor color for both x- and y-axis borders. 
+#'          If set, overrides both \code{axis.linecolor.x} and \code{axis.linecolor.y}.
+#' @param axis.line.size size (thickness) of axis lines. Only affected, if \code{axis.linecolor}
+#'          is set.
+#' @param axis.textsize.x size of x-axis labels
+#' @param axis.textsize.y size of y-axis labels
+#' @param axis.textsize size for both x- and y-axis labels. 
+#'          If set, overrides both \code{axis.textsize.x} and \code{axis.textsize.y}.
+#' @param axis.tickslen length of axis tick marks
+#' @param axis.ticksol color of axis tick marks
+#' @param axis.ticksmar margin between axis labels and tick marks
+#' @param panel.bordercol color of whole diagram border (panel border)
+#' @param panel.backcol color of the diagram's background
+#' @param panel.col color of both diagram's border and background.
+#'          If set, overrides both \code{panel.bordercol} and \code{panel.backcol}.
+#' @param panel.major.gridcol color of the major grid lines of the diagram background
+#' @param panel.minor.gridcol color of the minor grid lines of the diagram background
+#' @param panel.gridcol color for both minor and major grid lines of the diagram background.
+#'          If set, overrides both \code{panel.major.gridcol} and \code{panel.minor.gridcol}.
+#' @param panel.major.linetype line type for major grid lines
+#' @param panel.minor.linetype line type for minor grid lines
+#' @param plot.backcol color of the plot's background
+#' @param plot.bordercol color of whole plot's border (panel border)
+#' @param plot.col color of both plot's region border and background.
+#'          If set, overrides both \code{plot.backcol} and \code{plot.bordercol}.
+#' @param legend.pos position of the legend, if a legend is drawn.
+#'          \describe{
+#'            \item{\emph{legend outside plot}}{
+#'              Use \code{"bottom"}, \code{"top"}, \code{"left"} or \code{"right"} 
+#'              to position the legend above, below, on the left or right side 
+#'              of the diagram. Right positioning is default.
+#'            }
+#'            \item{\emph{legend inside plot}}{
+#'              If \code{legend.inside = TRUE}, legend can be placed inside
+#'              plot. Use \code{"top left"}, \code{"top right"}, \code{"bottom left"} 
+#'              and \code{"bottom right"} to position legend in any of these corners, 
+#'              or a two-element numeric vector with values from 0-1. See also 
+#'              \code{legend.inside}.
+#'            }
+#'          }
+#' @param legend.just justification of legend, relative to its position (\code{"center"} or 
+#'          two-element numeric vector with values from 0-1. By default (outside legend),
+#'          justification is centered. If legend is inside and justification not specified,
+#'          legend justification is set according to legend position.
+#' @param legend.inside logical, use \code{TRUE} to put legend inside the plotting area. See \code{legend.pos}.
+#' @param legend.size text size of the legend. Default is 1. Relative size, so 
+#'          recommended values are from 0.3 to 2.5
+#' @param legend.color color of the legend labels
+#' @param legend.title.size text size of the legend title
+#' @param legend.title.color color of the legend title
+#' @param legend.title.face font face of the legend title. By default, \code{"bold"} face is used.
+#' @param legend.bordercol color of the legend's border. Default is \code{"white"}, so no visible border is drawn.
+#' @param legend.backgroundcol fill color of the legend's background. Default is \code{"white"}, so no visible background is drawn.
+#' @param legend.item.bordercol color of the legend's item-border. Default is \code{"white"}.
+#' @param legend.item.backcol fill color of the legend's item-background. Default is \code{"grey90"}.
+#' @param base base theme where theme is built on. By default, all 
+#'          metrics from \code{theme_gray()} are used. See 'Details'.
 #' 
-#' @return The customized theme object, or \code{NULL}, if a ggplot-theme
-#'           was used.
+#' @return The customized theme object, or \code{NULL}, if a ggplot-theme was used.
 #' 
 #' @details If the \code{theme} parameter is one of the valid ggplot-themes, this theme
 #'            will be used and all further parameters will be ignored. If you want to modify
-#'            a ggplot-theme, use \code{base = "theme_xy"} and then further parameters to
+#'            a ggplot-theme, use \code{base = "theme_xy"}, then further parameters to
 #'            this function will be applied to the theme as well.
 #'            \cr \cr
 #'            If the \code{theme} parameter is one of sjPlot-pre-set-themes, you
@@ -143,9 +147,7 @@
 #' # legends of all plots inside
 #' sjp.setTheme(legend.pos = "top left", 
 #'              legend.inside = TRUE)
-#' sjp.xtab(efc$e42dep, 
-#'          efc$e16sex,
-#'          showTableSummary = FALSE)
+#' sjp.xtab(efc$e42dep, efc$e16sex)
 #' 
 #' # Use classic-theme. you may need to
 #' # load the ggplot2-library.
@@ -161,7 +163,6 @@
 #' update_geom_defaults('text', list(hjust = -0.1))
 #' sjp.xtab(efc$e42dep, 
 #'          efc$e16sex,
-#'          showTableSummary = FALSE,
 #'          labelPos = "center")
 #' 
 #' # Create own theme based on classic-theme
@@ -170,8 +171,7 @@
 #'              axis.textcolor = "#6699cc")
 #' sjp.frq(efc$e42dep)
 #'
-#' # use theme pre-set, taken from tutorial
-#' # http://minimaxir.com/2015/02/ggplot-tutorial/
+#' # use theme pre-set
 #' sjp.setTheme(theme = "538",
 #'              geom.alpha = 0.8)
 #' library(ggplot2) # for custom base-line
@@ -187,77 +187,78 @@
 #' @importFrom grid unit
 #' @importFrom scales brewer_pal grey_pal
 #' @export
-sjp.setTheme <- function(title.color="black",
-                         title.size=1.3,
+sjp.setTheme <- function(# base theme
+                         theme = NULL,
+                         # title defaults
+                         title.color = "black",
+                         title.size = 1.3,
                          title.align = "left",
                          # geom defaults
                          # geom.colors=NULL,
-                         geom.outline.color=NULL,
-                         geom.outline.size=0.1,
-                         geom.boxoutline.size=0.5,
-                         geom.boxoutline.color="black",
-                         geom.alpha=1,
-                         geom.linetype=1,
-                         geom.errorbar.size=0.7,
-                         geom.errorbar.linetype=1,
+                         geom.outline.color = NULL,
+                         geom.outline.size = 0.1,
+                         geom.boxoutline.size = 0.5,
+                         geom.boxoutline.color = "black",
+                         geom.alpha = 1,
+                         geom.linetype = 1,
+                         geom.errorbar.size = 0.7,
+                         geom.errorbar.linetype = 1,
                          # value labels
-                         geom.label.color=NULL,
-                         geom.label.size=4.5,
-                         geom.label.alpha=1,
-                         geom.label.angle=0,
+                         geom.label.color = NULL,
+                         geom.label.size = 4.5,
+                         geom.label.alpha = 1,
+                         geom.label.angle = 0,
                          # axis titles
-                         axis.title.color="grey30",
-                         axis.title.size=1.2,
+                         axis.title.color = "grey30",
+                         axis.title.size = 1.2,
                          # axis text angle
-                         axis.angle.x=0,
-                         axis.angle.y=0,
-                         axis.angle=NULL,
+                         axis.angle.x = 0,
+                         axis.angle.y = 0,
+                         axis.angle = NULL,
                          # axis text colors
-                         axis.textcolor.x="grey30",
-                         axis.textcolor.y="grey30",
-                         axis.textcolor=NULL,
+                         axis.textcolor.x = "grey30",
+                         axis.textcolor.y = "grey30",
+                         axis.textcolor = NULL,
                          # axis line colors
-                         axis.linecolor.x=NULL,
-                         axis.linecolor.y=NULL,
-                         axis.linecolor=NULL,
-                         axis.line.size=0.5,
+                         axis.linecolor.x = NULL,
+                         axis.linecolor.y = NULL,
+                         axis.linecolor = NULL,
+                         axis.line.size = 0.5,
                          # axis text size
-                         axis.textsize.x=1.1,
-                         axis.textsize.y=1.1,
-                         axis.textsize=NULL,
+                         axis.textsize.x = 1.1,
+                         axis.textsize.y = 1.1,
+                         axis.textsize = NULL,
                          # axis ticks
-                         axis.tickslen=NULL,
-                         axis.ticksol=NULL,
-                         axis.ticksmar=NULL,
+                         axis.tickslen = NULL,
+                         axis.ticksol = NULL,
+                         axis.ticksmar = NULL,
                          # panel defaults
-                         panel.backcol=NULL,
-                         panel.bordercol=NULL,
-                         panel.col=NULL,
-                         panel.major.gridcol=NULL,
-                         panel.minor.gridcol=NULL,
-                         panel.gridcol=NULL,
+                         panel.backcol = NULL,
+                         panel.bordercol = NULL,
+                         panel.col = NULL,
+                         panel.major.gridcol = NULL,
+                         panel.minor.gridcol = NULL,
+                         panel.gridcol = NULL,
                          panel.major.linetype = 1,
                          panel.minor.linetype = 1,
                          # plot background color
-                         plot.backcol=NULL,
-                         plot.bordercol=NULL,
-                         plot.col=NULL,
+                         plot.backcol = NULL,
+                         plot.bordercol = NULL,
+                         plot.col = NULL,
                          # legend
-                         legend.pos="right",
-                         legend.just=NULL,
-                         legend.inside=FALSE,
-                         legend.size=1,
-                         legend.color="black",
-                         legend.title.size=1,
-                         legend.title.color="black",
-                         legend.title.face="bold",
-                         legend.backgroundcol="white",
-                         legend.bordercol="white",
-                         legend.item.backcol="grey90",
-                         legend.item.bordercol="white",
-                         # base theme
-                         theme=NULL,
-                         base=theme_grey()) {
+                         legend.pos = "right",
+                         legend.just = NULL,
+                         legend.inside = FALSE,
+                         legend.size = 1,
+                         legend.color = "black",
+                         legend.title.size = 1,
+                         legend.title.color = "black",
+                         legend.title.face = "bold",
+                         legend.backgroundcol = "white",
+                         legend.bordercol = "white",
+                         legend.item.backcol = "grey90",
+                         legend.item.bordercol = "white",
+                         base = theme_grey()) {
   sjtheme <- NULL
   title.vjust <- NULL
   axis.title.x.vjust <- NULL
@@ -317,10 +318,10 @@ sjp.setTheme <- function(title.color="black",
   # check for grey-scaled 539 theme, which are
   # alternatives to 538
   # ----------------------------------------  
-  if (!is.null(theme) && (theme == "539" || theme == "539w" || theme == "forestgrey")) {
+  if (!is.null(theme) && (theme == "539" || theme == "539w" || theme == "forestgrey" || theme == "forestw")) {
     base <- theme_bw()
     g.palette <- scales::brewer_pal(palette = "Greys")(9)
-    col.ind <- ifelse(theme == "539w", 1, 2)
+    col.ind <- ifelse(theme == "539w" || theme == "forestw", 1, 2)
     panel.bordercol <- panel.backcol <- panel.col <- g.palette[col.ind]
     plot.backcol <- plot.bordercol <- plot.col <- g.palette[col.ind]
     if (theme == "539" || theme == "539w") {
@@ -378,7 +379,7 @@ sjp.setTheme <- function(title.color="black",
     title.vjust <- 1.75
     plot.margins <- unit(c(1, .5, 1, 0.5), "cm")
   }  
-  if (!is.null(theme) && theme=="blues") {
+  if (!is.null(theme) && theme == "blues") {
     base <- theme_bw()
     g.palette <- scales::brewer_pal(palette = "Blues")(9)
     panel.bordercol <- panel.backcol <- panel.col <- g.palette[1]
@@ -404,7 +405,7 @@ sjp.setTheme <- function(title.color="black",
     title.vjust <- 1.75
     plot.margins <- unit(c(1, .5, 1, 0.5), "cm")
   }  
-  if (!is.null(theme) && theme=="greens") {
+  if (!is.null(theme) && theme == "greens") {
     base <- theme_bw()
     g.palette <- scales::brewer_pal(palette = "BrBG")(9)
     g.palette[5] <- "#f5faf5"
@@ -442,8 +443,7 @@ sjp.setTheme <- function(title.color="black",
   # ----------------------------------------  
   if (!is.null(axis.angle)) {
     axis.angle.x <- axis.angle.y <- axis.angle 
-  }
-  else {
+  } else {
     axis.angle <- axis.angle.x
   }
   # ----------------------------------------
@@ -451,8 +451,7 @@ sjp.setTheme <- function(title.color="black",
   # ----------------------------------------  
   if (!is.null(axis.textcolor)) {
     axis.textcolor.x <- axis.textcolor.y <- axis.textcolor
-  }
-  else {
+  } else {
     if (is.null(axis.textcolor.x)) 
       axis.textcolor <- axis.textcolor.y 
     else 
@@ -463,8 +462,7 @@ sjp.setTheme <- function(title.color="black",
   # ----------------------------------------  
   if (!is.null(axis.linecolor)) {
     axis.linecolor.x <- axis.linecolor.y <- axis.linecolor
-  }
-  else {
+  } else {
     if (is.null(axis.linecolor.x)) 
       axis.linecolor <- axis.linecolor.y 
     else 
@@ -475,8 +473,7 @@ sjp.setTheme <- function(title.color="black",
   # ----------------------------------------
   if (!is.null(axis.textsize)) {
     axis.textsize.x <- axis.textsize.y <- axis.textsize
-  }
-  else {
+  } else {
     if (is.null(axis.textsize.x)) 
       axis.textsize <- axis.textsize.y 
     else 
@@ -487,8 +484,7 @@ sjp.setTheme <- function(title.color="black",
   # ----------------------------------------
   if (!is.null(panel.gridcol)) {
     panel.major.gridcol <- panel.minor.gridcol <- panel.gridcol
-  }
-  else {
+  } else {
     if (is.null(panel.major.gridcol)) 
       panel.gridcol <- panel.minor.gridcol 
     else 
@@ -499,8 +495,7 @@ sjp.setTheme <- function(title.color="black",
   # ----------------------------------------
   if (!is.null(panel.col)) {
     panel.backcol <- panel.bordercol <- panel.col
-  }
-  else {
+  } else {
     if (is.null(panel.backcol)) 
       panel.col <- panel.bordercol 
     else 
@@ -513,8 +508,7 @@ sjp.setTheme <- function(title.color="black",
     if (title.align == "left" || title.align == "l") title.align <- 0
     if (title.align == "right" || title.align == "r") title.align <- 1
     if (title.align == "center" || title.align == "c") title.align <- 0.5
-  }
-  else {
+  } else {
     title.align <- 0
   }
   # ----------------------------------------
@@ -522,8 +516,7 @@ sjp.setTheme <- function(title.color="black",
   # ----------------------------------------
   if (!is.null(plot.col)) {
     plot.backcol <- plot.bordercol <- plot.col
-  }
-  else {
+  } else {
     if (is.null(plot.backcol)) 
       plot.col <- plot.bordercol 
     else 
@@ -548,13 +541,13 @@ sjp.setTheme <- function(title.color="black",
   # ----------------------------------------
   # check if theme-preset is requested
   # ----------------------------------------
-  if (!is.null(theme) && any(class(theme)=="theme") && any(class(theme)=="gg")) {
+  if (!is.null(theme) && any(class(theme) == "theme") && any(class(theme) == "gg")) {
     theme_set(theme)
   }
   # ----------------------------------------
   # else, customize theme
   # ----------------------------------------
-  else if (!is.null(base) && any(class(base)=="theme") && any(class(base)=="gg")) {
+  else if (!is.null(base) && any(class(base) == "theme") && any(class(base) == "gg")) {
     sjtheme <- base +
       # ----------------------------------------
       # set base elements that are always set
@@ -783,11 +776,12 @@ sj.setGeomColors <- function(plot,
       plot <- plot + 
         scale_fill_manual(values = geom.colors, guide = FALSE) +
         scale_colour_manual(values = geom.colors, guide = FALSE) +
-        guides(fill = FALSE)
+        guides(fill = FALSE, colour = FALSE, text = FALSE)
     } else {
       plot <- plot + 
         scale_fill_manual(values = geom.colors, labels = labels) +
-        scale_colour_manual(values = geom.colors, labels = labels)
+        scale_colour_manual(values = geom.colors, labels = labels) +
+        guides(text = FALSE)
     }
     return(plot)
   }
@@ -800,11 +794,12 @@ sj.setGeomColors <- function(plot,
       plot <- plot + 
         scale_fill_discrete(guide = FALSE) +
         scale_colour_discrete(guide = FALSE) +
-        guides(fill = FALSE)
+        guides(fill = FALSE, colour = FALSE, text = FALSE)
     } else {
       plot <- plot + 
         scale_fill_discrete(labels = labels) +
-        scale_colour_discrete(labels = labels)
+        scale_colour_discrete(labels = labels) +
+        guides(text = FALSE)
     }
     return(plot)
   }
