@@ -1,4 +1,4 @@
-#' @title Show grouped means as HTML table
+#' @title Summary of grouped means as HTML table
 #' @name sjt.grpmean
 #' 
 #' @description Computes mean, sd and se for each sub-group (indicated by \code{varGrp})
@@ -16,23 +16,9 @@
 #'          are automatically detected if set by \code{\link[sjmisc]{set_val_labels}}.
 #' @param digits amount of digits for table values.
 #' @param digits.summary amount of digits for summary statistics (Anova).
-#' @param file The destination file, which will be in html-format. If no filepath is specified,
-#'          the file will be saved as temporary file and openend either in the RStudio View pane or
-#'          in the default web browser.
-#' @param encoding The charset encoding used for variable and value labels. Default is \code{NULL}, so encoding
-#'          will be auto-detected depending on your platform (\code{"UTF-8"} for Unix and \code{"Windows-1252"} for
-#'          Windows OS). Change encoding if specific chars are not properly displayed (e.g.) German umlauts).
-#' @param CSS A \code{\link{list}} with user-defined style-sheet-definitions, according to the 
-#'          \href{http://www.w3.org/Style/CSS/}{official CSS syntax}. See 'Details'.
-#' @param useViewer If \code{TRUE}, the function tries to show the HTML table in the IDE's viewer pane. If
-#'          \code{FALSE} or no viewer available, the HTML table is opened in a web browser.
-#' @param no.output If \code{TRUE}, the html-output is neither opened in a browser nor shown in
-#'          the viewer pane and not even saved to file. This option is useful when the html output
-#'          should be used in \code{knitr} documents. The html output can be accessed via the return
-#'          value.
-#' @param remove.spaces logical, if \code{TRUE}, leading spaces are removed from all lines in the final string
-#'          that contains the html-data. Use this, if you want to remove parantheses for html-tags. The html-source
-#'          may look less pretty, but it may help when exporting html-tables to office tools.
+#' 
+#' @inheritParams sjt.frq
+#' 
 #' @return Invisibly returns a \code{\link{list}} with
 #'          \itemize{
 #'            \item the data frame with the description information (\code{df}),
@@ -45,7 +31,16 @@
 #'
 #' @note See 'Notes' in \code{\link{sjt.frq}}.
 #'  
-#' @details See 'Details' in \code{\link{sjt.frq}}.
+#' @details This function performs a One-Way-Anova with \code{varCount} as dependent
+#'            and \code{varGrp} as independent variable, by calling
+#'            \code{lm(varCount ~ as.factor(varGrp))}, to get p-values for each
+#'            sub-group and the complete "model". Thus, p-values indicate whether
+#'            each group-mean is significantly different from the reference 
+#'            group (reference level of \code{varGrp}). Statistics like mean values are
+#'            based on subsetted groups (i.e. \code{varCount} is divided into sub-groups
+#'            indicated by \code{varGrp}).
+#'            \cr \cr
+#'            Furthermore, see 'Details' in \code{\link{sjt.frq}}.
 #'
 #' @examples
 #' \dontrun{
@@ -55,6 +50,7 @@
 #'             efc$e42dep)}
 #'             
 #' @import sjmisc
+#' @importFrom stats na.omit lm
 #' @export
 sjt.grpmean <- function(varCount, 
                         varGrp, 
@@ -98,9 +94,9 @@ sjt.grpmean <- function(varCount,
   # see below
   # --------------------------------------
   if (!is.null(weightBy)) {
-    fit <- lm(varCount ~ as.factor(varGrp), weights = weightBy)
+    fit <- stats::lm(varCount ~ as.factor(varGrp), weights = weightBy)
   } else {
-    fit <- lm(varCount ~ as.factor(varGrp))
+    fit <- stats::lm(varCount ~ as.factor(varGrp))
   }
   # get model summary
   sum.fit <- summary(fit)
@@ -118,7 +114,7 @@ sjt.grpmean <- function(varCount,
   # --------------------------------------
   # retrieve group indices
   # --------------------------------------
-  indices <- sort(unique(na.omit(varGrp)))
+  indices <- sort(unique(stats::na.omit(varGrp)))
   df <- data.frame()
   # --------------------------------------
   # iterate all groups
@@ -141,7 +137,7 @@ sjt.grpmean <- function(varCount,
     # --------------------------------------
     df <- rbind(df, 
                 cbind(mean = sprintf("%.*f", digits, mw),
-                      N = length(na.omit(varCount[varGrp == indices[i]])),
+                      N = length(stats::na.omit(varCount[varGrp == indices[i]])),
                       sd = sprintf("%.*f", digits, sd(varCount[varGrp == indices[i]], na.rm = TRUE)),
                       se = sprintf("%.*f", digits, sjmisc::std_e(varCount[varGrp == indices[i]])),
                       p = pval[i]))
@@ -161,7 +157,7 @@ sjt.grpmean <- function(varCount,
   # --------------------------------------
   df <- rbind(df, 
               cbind(mean = sprintf("%.*f", digits, mw),
-                    N = length(na.omit(varCount)),
+                    N = length(stats::na.omit(varCount)),
                     sd = sprintf("%.*f", digits, sd(varCount, na.rm = TRUE)),
                     se = sprintf("%.*f", digits, sjmisc::std_e(varCount)),
                     p = ""))
@@ -213,4 +209,4 @@ sjt.grpmean <- function(varCount,
                  page.content = html$page.content,
                  knitr = html$knitr,
                  output.complete = html$output.complete))
-}
\ No newline at end of file
+}
