@@ -1,8 +1,8 @@
 # bind global variables
-if (getRversion() >= "2.15.1") utils::globalVariables(c("starts_with"))
+utils::globalVariables(c("starts_with"))
 
 
-#' @title Show linear regression as HTML table
+#' @title Summary of linear regression as HTML table
 #' @name sjt.lm
 #' 
 #' @description Summarizes (multiple) fitted linear models (beta coefficients, std. beta values etc.)
@@ -11,64 +11,65 @@ if (getRversion() >= "2.15.1") utils::globalVariables(c("starts_with"))
 #'                
 #' @seealso \href{http://strengejacke.de/sjPlot/sjt.lm/}{sjPlot manual: sjt.lm}
 #' 
-#' @param ... One or more fitted lm-objects.
-#' @param file The destination file, which will be in html-format. If no filepath is specified,
-#'          the file will be saved as temporary file and openend either in the RStudio View pane or
-#'          in the default web browser.
-#' @param labelPredictors Labels of the predictor variables, provided as char vector.
-#' @param labelDependentVariables Labels of the dependent variables of all fitted models
-#'          which have been used as first parameter(s), provided as char vector.
-#' @param stringPredictors String constant used as headline for the predictor column.
+#' @param ... one or more fitted linear (mixed) models.
+#' @param labelPredictors character vector with labels of predictor variables.
+#'          If not \code{NULL}, \code{labelPredictors} will be used in the first
+#'          table column with the predictors' names. See 'Examples'.
+#' @param labelDependentVariables character vector with labels of dependent 
+#'          variables of all fitted models. See 'Examples'.
+#' @param stringPredictors string constant used as headline for the predictor column.
 #'          Default is \code{"Predictors"}.
-#' @param stringDependentVariables String constant used as headline for the 
+#' @param stringDependentVariables string constant used as headline for the 
 #'          dependent variable columns. Default is \code{"Dependent Variables"}.
-#' @param showHeaderStrings If \code{TRUE}, the header strings \code{stringPredictors}
+#' @param showHeaderStrings logical, if \code{TRUE}, the header strings \code{stringPredictors}
 #'          and \code{stringDependentVariables} are shown. By default, they're hidden.
-#' @param stringModel String constant used as headline for the model names in case no 
+#' @param stringModel string constant used as headline for the model names in case no 
 #'          labels for the dependent variables are provided (see labelDependentVariables).
 #'          Default is \code{"Model"}.
-#' @param stringIntercept String constant used as headline for the Intercept row
-#'          default is \code{"Intercept"}.
-#' @param stringObservations String constant used in the summary row for the count of observation
+#' @param stringIntercept string constant used as headline for the Intercept row.
+#'          Default is \code{"Intercept"}.
+#' @param stringObservations string constant used in the summary row for the count of observation
 #'          (cases). Default is \code{"Observations"}.
-#' @param stringB String used for the column heading of beta coefficients. Default is \code{"B"}.
-#' @param stringSB String used for the column heading of standardized beta coefficients. Default is \code{"std. Beta"}.
-#' @param stringCI String used for the column heading of confidence interval values. Default is \code{"CI"}.
-#' @param stringSE String used for the column heading of standard error values. Default is \code{"std. Error"}.
-#' @param stringP String used for the column heading of p values. Default is \code{"p"}.
-#' @param showEst If \code{TRUE} (default), the estimates are printed.
-#' @param showConfInt If \code{TRUE} (default), the confidence intervall is also printed to the table. Use
+#' @param stringB string used for the column heading of beta coefficients. Default is \code{"B"}.
+#' @param stringSB string used for the column heading of standardized beta coefficients. Default is \code{"std. Beta"}.
+#' @param stringCI string used for the column heading of confidence interval values. Default is \code{"CI"}.
+#' @param stringSE string used for the column heading of standard error values. Default is \code{"std. Error"}.
+#' @param stringP string used for the column heading of p values. Default is \code{"p"}.
+#' @param showEst logical, if \code{TRUE} (default), the estimates are printed.
+#' @param showConfInt logical, if \code{TRUE} (default), the confidence intervall is also printed to the table. Use
 #'          \code{FALSE} to omit the CI in the table.
-#' @param showStdBeta If \code{TRUE}, the standardized beta-coefficients are also printed.
+#' @param showStdBeta logical, if \code{TRUE}, the standardized beta-coefficients are also printed.
 #'          Default is \code{FALSE}.
-#' @param showStdError If \code{TRUE}, the standard errors are also printed.
+#' @param showStdError logical, if \code{TRUE}, the standard errors are also printed.
 #'          Default is \code{FALSE}.
-#' @param digits.est Amount of decimals for estimators.
-#' @param digits.p Amount of decimals for p-values.
-#' @param digits.ci Amount of decimals for confidence intervals.
-#' @param digits.se Amount of decimals for standard error.
-#' @param digits.sb Amount of decimals for standardized beta.
-#' @param digits.summary Amount of decimals for values in model summary.
-#' @param pvaluesAsNumbers If \code{TRUE}, p-values are shown as numbers. If \code{FALSE} (default),
+#' @param digits.est amount of decimals for estimators
+#' @param digits.p amount of decimals for p-values
+#' @param digits.ci amount of decimals for confidence intervals
+#' @param digits.se amount of decimals for standard error
+#' @param digits.sb amount of decimals for standardized beta
+#' @param digits.summary amount of decimals for values in model summary
+#' @param pvaluesAsNumbers logical, if \code{TRUE}, p-values are shown as numbers. If \code{FALSE} (default),
 #'          p-values are indicated by asterisks.
-#' @param boldpvalues If \code{TRUE} (default), significant p-values are shown bold faced.
+#' @param boldpvalues logical, if \code{TRUE} (default), significant p-values are shown bold faced.
 #' @param separateConfColumn if \code{TRUE}, the CI values are shown in a separate table column.
 #'          Default is \code{FALSE}.
-#' @param newLineConf If \code{TRUE} and \code{separateConfColumn} is \code{FALSE}, inserts a line break
+#' @param newLineConf logica, if \code{TRUE} and \code{separateConfColumn = FALSE}, inserts a line break
 #'          between B and CI values. If \code{FALSE}, CI values are printed in the same
 #'          line with B values.
 #' @param group.pred logical, if \code{TRUE} (default), automatically groups table rows with 
 #'          factor levels of same factor, i.e. predictors of type \code{\link{factor}} will
 #'          be grouped, if the factor has more than two levels. Grouping means that a separate headline
 #'          row is inserted to the table just before the predictor values.
-#' @param showAbbrHeadline If \code{TRUE} (default), the table data columns have a headline with 
+#' @param showAbbrHeadline logical, if \code{TRUE} (default), the table data columns have a headline with 
 #'          abbreviations for beta- and std. beta-values, confidence interval and p-values.
-#' @param showR2 If \code{TRUE} (default), the R2 and adjusted R2 values for each model are printed
+#' @param showR2 logical, if \code{TRUE} (default), the R2 and adjusted R2 values for each model are printed
 #'          in the model summary.
 #' @param showFStat If \code{TRUE}, the F-statistics for each model is printed
 #'          in the model summary. Default is \code{FALSE}.
 #' @param showAIC If \code{TRUE}, the AIC value for each model is printed
 #'          in the model summary. Default is \code{FALSE}.
+#' @param showAICc If \code{TRUE}, the second-order AIC value for each model 
+#'          is printed in the model summary. Default is \code{FALSE}.
 #' @param remove.estimates numeric vector with indices (order equals to row index of \code{coef(fit)}) 
 #'          or character vector with coefficient names that indicate which estimates should be removed
 #'          from the table output. The first estimate is the intercept, followed by the model predictors.
@@ -76,26 +77,15 @@ if (getRversion() >= "2.15.1") utils::globalVariables(c("starts_with"))
 #'          would remove the 2nd to the 4th estimate (1st to 3d predictor after intercept) from the output. 
 #'          \code{remove.estimates = "est_name"} would remove the estimate \emph{est_name}. Default 
 #'          is \code{NULL}, i.e. all estimates are printed.
-#' @param cellSpacing The inner padding of table cells. By default, this value is 0.2 (unit is cm), which is
+#' @param cellSpacing numeric, inner padding of table cells. By default, this value is 0.2 (unit is cm), which is
 #'          suitable for viewing the table. Decrease this value (0.05 to 0.1) if you want to import the table
 #'          into Office documents. This is a convenient parameter for the \code{CSS} parameter for changing
-#'          cell spacing, which would be: \code{CSS=list(css.thead="padding:0.2cm;", css.tzdata="padding:0.2cm;")}.
+#'          cell spacing, which would be: \code{CSS = list(css.thead = "padding:0.2cm;", css.tdata = "padding:0.2cm;")}.
 #' @param cellGroupIndent Indent for table rows with grouped factor predictors. Only applies
 #'          if \code{group.pred} is \code{TRUE}.
-#' @param encoding The charset encoding used for variable and value labels. Default is \code{NULL}, so encoding
-#'          will be auto-detected depending on your platform (\code{"UTF-8"} for Unix and \code{"Windows-1252"} for
-#'          Windows OS). Change encoding if specific chars are not properly displayed (e.g.) German umlauts).
-#' @param CSS A \code{\link{list}} with user-defined style-sheet-definitions, according to the 
-#'          \href{http://www.w3.org/Style/CSS/}{official CSS syntax}. See 'Details'.
-#' @param useViewer If \code{TRUE}, the function tries to show the HTML table in the IDE's viewer pane. If
-#'          \code{FALSE} or no viewer available, the HTML table is opened in a web browser.
-#' @param no.output If \code{TRUE}, the html-output is neither opened in a browser nor shown in
-#'          the viewer pane and not even saved to file. This option is useful when the html output
-#'          should be used in \code{knitr} documents. The html output can be accessed via the return
-#'          value.
-#' @param remove.spaces logical, if \code{TRUE}, leading spaces are removed from all lines in the final string
-#'          that contains the html-data. Use this, if you want to remove parantheses for html-tags. The html-source
-#'          may look less pretty, but it may help when exporting html-tables to office tools.
+#'          
+#' @inheritParams sjt.frq
+#'          
 #' @return Invisibly returns
 #'          \itemize{
 #'            \item the web page style sheet (\code{page.style}),
@@ -335,49 +325,51 @@ if (getRversion() >= "2.15.1") utils::globalVariables(c("starts_with"))
 #'                   css.modelcolumn5 = 'padding-right:50px;'))}
 #'                   
 #' @import dplyr
+#' @importFrom stats nobs AIC confint coef
 #' @export
-sjt.lm <- function (..., 
-                    file=NULL, 
-                    labelPredictors=NULL, 
-                    labelDependentVariables=NULL, 
-                    stringPredictors="Predictors", 
-                    stringDependentVariables="Dependent Variables", 
-                    stringModel="Model",
-                    showHeaderStrings=FALSE,
-                    stringIntercept="(Intercept)",
-                    stringObservations="Observations",
-                    stringB="B",
-                    stringSB="std. Beta",
-                    stringCI="CI",
-                    stringSE="std. Error",
-                    stringP="p",
-                    showEst=TRUE,
-                    showConfInt=TRUE,
-                    showStdBeta=FALSE,
-                    showStdError=FALSE,
-                    digits.est=2,
-                    digits.p=3,
-                    digits.ci=2,
-                    digits.se=2,
-                    digits.sb=2,
-                    digits.summary=3,
-                    pvaluesAsNumbers=TRUE,
-                    boldpvalues=TRUE,
-                    separateConfColumn=TRUE,
-                    newLineConf=TRUE,
-                    group.pred=TRUE,
-                    showAbbrHeadline=TRUE,
-                    showR2=TRUE,
-                    showFStat=FALSE,
-                    showAIC=FALSE,
-                    remove.estimates=NULL,
-                    cellSpacing=0.2,
-                    cellGroupIndent=0.6,
-                    encoding=NULL,
-                    CSS=NULL,
-                    useViewer=TRUE,
-                    no.output=FALSE,
-                    remove.spaces=TRUE) {
+sjt.lm <- function(...,
+                   file = NULL,
+                   labelPredictors = NULL,
+                   labelDependentVariables = NULL,
+                   stringPredictors = "Predictors",
+                   stringDependentVariables = "Dependent Variables",
+                   stringModel = "Model",
+                   showHeaderStrings = FALSE,
+                   stringIntercept = "(Intercept)",
+                   stringObservations = "Observations",
+                   stringB = "B",
+                   stringSB = "std. Beta",
+                   stringCI = "CI",
+                   stringSE = "std. Error",
+                   stringP = "p",
+                   showEst = TRUE,
+                   showConfInt = TRUE,
+                   showStdBeta = FALSE,
+                   showStdError = FALSE,
+                   digits.est = 2,
+                   digits.p = 3,
+                   digits.ci = 2,
+                   digits.se = 2,
+                   digits.sb = 2,
+                   digits.summary = 3,
+                   pvaluesAsNumbers = TRUE,
+                   boldpvalues = TRUE,
+                   separateConfColumn = TRUE,
+                   newLineConf = TRUE,
+                   group.pred = TRUE,
+                   showAbbrHeadline = TRUE,
+                   showR2 = TRUE,
+                   showFStat = FALSE,
+                   showAIC = FALSE,
+                   showAICc = FALSE,
+                   remove.estimates = NULL,
+                   cellSpacing = 0.2,
+                   cellGroupIndent = 0.6,
+                   encoding = NULL,
+                   CSS = NULL,
+                   useViewer = TRUE,
+                   no.output = FALSE,
+                   remove.spaces = TRUE) {
   # --------------------------------------------------------
   # check p-value-style option
   # --------------------------------------------------------
@@ -550,6 +542,15 @@ sjt.lm <- function (...,
   if (lmerob && !requireNamespace("lme4", quietly = TRUE)) {
     stop("Package 'lme4' needed for this function to work. Please install it.", call. = FALSE)
   }
+  # ------------------------
+  # should AICc be computed? Check for package
+  # ------------------------
+  if (showAICc && !requireNamespace("AICcmodavg", quietly = TRUE)) {
+    warning("Package 'AICcmodavg' needed to show AICc. Parameter 'showAICc' will be ignored.", call. = FALSE)
+    showAICc <- FALSE
+  }
+  
+  
   # ------------------------
   # check for stepwise models, when fitted models
   # are mixed effects models
@@ -605,7 +606,8 @@ sjt.lm <- function (...,
     # retrieve ci for model
     # -------------------------------------
     if (lmerob) {
-      confis <- lme4::confint.merMod(fit, method = "Wald")
+      # get cleaned CI
+      confis <- get_cleaned_ciMerMod(fit, T)
       sbmer <- suppressWarnings(sjmisc::std_beta(fit)[-1, ])
       sbvals <- data.frame(beta = sbmer[, 1], 
                            ci.low = sbmer[, 1] - 1.96 * sbmer[, 2],
@@ -613,9 +615,9 @@ sjt.lm <- function (...,
                            se = sbmer[, 2])
       coef.fit <- lme4::fixef(fit)
     } else {
-      confis <- confint(fit)
+      confis <- stats::confint(fit)
       sbvals <- suppressWarnings(sjmisc::std_beta(fit, include.ci = T))
-      coef.fit <- coef(fit)
+      coef.fit <- stats::coef(fit)
     }
     # -------------------------------------
     # write data to data frame. we need names of
@@ -664,7 +666,7 @@ sjt.lm <- function (...,
       }
       fit.df$pv <- sapply(fit.df$pv, function(x) {
         if (x < 0.05) {
-          if (x < 0.001) {
+          if (x < 0.001 && digits.p <= 3) {
             x <- sprintf("%s&lt;0.001%s", sb1, sb2)
           } else {
             x <- sprintf("%s%.*f%s", sb1, digits.p, x, sb2)
@@ -1020,10 +1022,6 @@ sjt.lm <- function (...,
     }
     page.content <- paste0(page.content, "\n  <tr>\n", sprintf("    <td class=\"%s leftalign\">%s</td>", indent.tag, labelPredictors[i]))
     # ---------------------------------------
-    # helper function, checks if string is empty
-    # ---------------------------------------
-    is_empty <- function(x) return(is.null(x) || nchar(x) == 0)
-    # ---------------------------------------
     # go through fitted model's statistics
     # ---------------------------------------
     for (j in 1:length(input_list)) {
@@ -1039,11 +1037,11 @@ sjt.lm <- function (...,
         # if we have empry cells (due to different predictors in models)
         # we don't print CI-separator strings and we don't print any esitmate
         # values - however, for proper display, we fill these values with "&nbsp;"
-        ci.sep.string <- ifelse(is_empty(ci.lo), "&nbsp;", "&nbsp;-&nbsp;")
+        ci.sep.string <- ifelse(sjmisc::is_empty(ci.lo), "&nbsp;", "&nbsp;-&nbsp;")
         # replace empty beta, se and p-values with &nbsp;
-        if (is_empty(joined.df[i + 1, (j - 1) * 8 + 2])) joined.df[i + 1, (j - 1) * 8 + 2] <- "&nbsp;"
-        if (is_empty(joined.df[i + 1, (j - 1) * 8 + 5])) joined.df[i + 1, (j - 1) * 8 + 5] <- "&nbsp;"
-        if (is_empty(joined.df[i + 1, (j - 1) * 8 + 6])) joined.df[i + 1, (j - 1) * 8 + 6] <- "&nbsp;"
+        if (sjmisc::is_empty(joined.df[i + 1, (j - 1) * 8 + 2])) joined.df[i + 1, (j - 1) * 8 + 2] <- "&nbsp;"
+        if (sjmisc::is_empty(joined.df[i + 1, (j - 1) * 8 + 5])) joined.df[i + 1, (j - 1) * 8 + 5] <- "&nbsp;"
+        if (sjmisc::is_empty(joined.df[i + 1, (j - 1) * 8 + 6])) joined.df[i + 1, (j - 1) * 8 + 6] <- "&nbsp;"
         # confidence interval in separate column
         if (separateConfColumn) {
           # open table cell for Beta-coefficient
@@ -1065,11 +1063,12 @@ sjt.lm <- function (...,
           page.content <- paste0(page.content, sprintf("\n    <td class=\"tdata centeralign modelcolumn1\">%s", 
                                                        joined.df[i + 1, (j - 1) * 8 + 2]))
           # confidence interval in Beta-column
-          if (showConfInt && !is_empty(ci.lo)) page.content <- paste0(page.content, sprintf("%s(%s%s%s)", 
-                                                                                            linebreakstring, 
-                                                                                            ci.lo, 
-                                                                                            ci.sep.string, 
-                                                                                            ci.hi))
+          if (showConfInt && !sjmisc::is_empty(ci.lo)) page.content <- paste0(page.content, 
+                                                                              sprintf("%s(%s%s%s)", 
+                                                                                      linebreakstring, 
+                                                                                      ci.lo, 
+                                                                                      ci.sep.string, 
+                                                                                      ci.hi))
           # if p-values are not shown as numbers, insert them after beta-value
           if (!pvaluesAsNumbers) page.content <- paste0(page.content, 
                                                         sprintf("&nbsp;%s", 
@@ -1086,7 +1085,7 @@ sjt.lm <- function (...,
         # retieve lower and upper ci
         ci.lo <- joined.df[i + 1, (j - 1) * 8 + 8]
         ci.hi <- joined.df[i + 1, (j - 1) * 8 + 9]
-        ci.sep.string <- ifelse(is_empty(ci.lo), "", "&nbsp;-&nbsp;")
+        ci.sep.string <- ifelse(sjmisc::is_empty(ci.lo), "", "&nbsp;-&nbsp;")
         if (separateConfColumn) {
           # open table cell for Beta-coefficient
           page.content <- paste0(page.content, sprintf("<td class=\"tdata centeralign modelcolumn4\">%s", joined.df[i + 1, (j - 1) * 8 + 7]))
@@ -1104,7 +1103,7 @@ sjt.lm <- function (...,
           # show pvalue stars, if no estimates are shown
           if (!pvaluesAsNumbers && !showEst) page.content <- paste0(page.content, sprintf("&nbsp;%s", joined.df[1, (i - 1) * 8 + 5]))
           # confidence interval in Beta-column
-          if (showConfInt && !is_empty(ci.lo)) page.content <- paste0(page.content, sprintf("%s(%s%s%s)", linebreakstring, ci.lo, ci.sep.string, ci.hi))
+          if (showConfInt && !sjmisc::is_empty(ci.lo)) page.content <- paste0(page.content, sprintf("%s(%s%s%s)", linebreakstring, ci.lo, ci.sep.string, ci.hi))
           # if p-values are not shown as numbers, insert them after beta-value
           page.content <- paste0(page.content, "</td>")
         }
@@ -1183,7 +1182,7 @@ sjt.lm <- function (...,
           # does model have enough icc values?
           # if yes, print
           if (length(sub.summary.icc) >= si) {
-            sum.icc.str <- paste0(sprintf("    %.*f", digits.summary, sub.summary.icc[si]), collapse = "")
+            sum.icc.str <- paste0(sprintf("%.*f", digits.summary, sub.summary.icc[si]), collapse = "")
             page.content <- paste0(page.content, colspanstring, sum.icc.str, "</td>\n")
           } else {
             page.content <- paste0(page.content, colspanstring, "&nbsp;</td>\n")
@@ -1209,7 +1208,7 @@ sjt.lm <- function (...,
       # "plm" seems not to offer a "nobs" function
       n_of_obs <- nrow(input_list[[i]]$model)
     } else {
-      n_of_obs <- nobs(input_list[[i]])
+      n_of_obs <- stats::nobs(input_list[[i]])
     }
     page.content <- paste(page.content, sprintf("   %s%i</td>\n", colspanstringfirstrow, n_of_obs))
   }
@@ -1272,7 +1271,21 @@ sjt.lm <- function (...,
       # insert "separator column"
       # -------------------------
       page.content <- paste0(page.content, "\n    <td class=\"separatorcol\">&nbsp;</td>")
-      page.content <- paste(page.content, sprintf("    %s%.*f</td>\n", colspanstring, digits.summary, AIC(input_list[[i]])))
+      page.content <- paste(page.content, sprintf("    %s%.*f</td>\n", colspanstring, digits.summary, stats::AIC(input_list[[i]])))
+    }
+    page.content <- paste0(page.content, "  </tr>\n")
+  }
+  # -------------------------------------
+  # Model-Summary: AICc
+  # -------------------------------------
+  if (showAICc) {
+    page.content <- paste(page.content, "  <tr>\n     <td class=\"tdata leftalign summary\">AICc</td>\n")
+    for (i in 1:length(input_list)) {
+      # -------------------------
+      # insert "separator column"
+      # -------------------------
+      page.content <- paste0(page.content, "\n    <td class=\"separatorcol\">&nbsp;</td>")
+      page.content <- paste(page.content, sprintf("    %s%.*f</td>\n", colspanstring, digits.summary, AICcmodavg::AICc(input_list[[i]])))
     }
     page.content <- paste0(page.content, "  </tr>\n")
   }
@@ -1355,31 +1368,7 @@ sjt.lm <- function (...,
 }
 
 
-
-# @title Show linear regression with mediator variable as HTML table
-# @name sjt.mlm
-# 
-# @description Shows fitted linear models with mediator effects
-#                as HTML table, or saves them as file.
-#                
-# @seealso \code{\link{sjt.glm}} \cr
-#          \code{\link{sjp.lm}} \cr
-#          \code{\link{sjp.lm1}} \cr
-#          \code{\link{sjt.lm}}
-#        
-# @export
-# sjt.mlm <- function(iv, dv, mv, controls=NULL, data) {
-#   col.iv <- which(colnames(data)==iv)
-#   col.dv <- which(colnames(data)==dv)
-#   col.mv <- which(colnames(data)==mv)
-#   fit <- lm(data[,col.iv]~data[,col.dv]+data[,col.mv], data, na.action="na.omit")
-#   fit
-# }
-
-# sjt.mlm("sgb_all", "sf12_ps", "fab3er_1r", data=kn)
-
-
-#' @title Show linear mixed effects models as HTML table
+#' @title Summary of linear mixed effects models as HTML table
 #' @name sjt.lmer
 #' 
 #' @description Summarizes (multiple) fitted linear mixed effects models 
@@ -1390,83 +1379,11 @@ sjt.lm <- function (...,
 #' @seealso \href{http://strengejacke.de/sjPlot/sjt.lmer/}{sjPlot manual: sjt.lmer} 
 #'            and \code{\link{sjt.lm}} for further examples.
 #' 
-#' @param ... One or more mixed models fitted with \code{\link[lme4]{lmer}} or \code{\link[lmerTest]{lmer}}.
-#' @param file The destination file, which will be in html-format. If no filepath is specified,
-#'          the file will be saved as temporary file and openend either in the RStudio View pane or
-#'          in the default web browser.
-#' @param labelPredictors Labels of the predictor variables, provided as char vector.
-#' @param labelDependentVariables Labels of the dependent variables of all fitted models
-#'          which have been used as first parameter(s), provided as char vector.
-#' @param stringPredictors String constant used as headline for the predictor column.
-#'          Default is \code{"Predictors"}.
-#' @param stringDependentVariables String constant used as headline for the 
-#'          dependent variable columns. Default is \code{"Dependent Variables"}.
-#' @param showHeaderStrings If \code{TRUE}, the header strings \code{stringPredictors}
-#'          and \code{stringDependentVariables} are shown. By default, they're hidden.
-#' @param stringModel String constant used as headline for the model names in case no 
-#'          labels for the dependent variables are provided (see labelDependentVariables).
-#'          Default is \code{"Model"}.
-#' @param stringIntercept String constant used as headline for the Intercept row
-#'          default is \code{"Intercept"}.
-#' @param stringObservations String constant used in the summary row for the count of observation
-#'          (cases). Default is \code{"Observations"}.
-#' @param stringB String used for the column heading of beta coefficients. Default is \code{"B"}.
-#' @param stringSB String used for the column heading of standardized beta coefficients. Default is \code{"std. Beta"}.
-#' @param stringCI String used for the column heading of confidence interval values. Default is \code{"CI"}.
-#' @param stringSE String used for the column heading of standard error values. Default is \code{"std. Error"}.
-#' @param stringP String used for the column heading of p values. Default is \code{"p"}.
-#' @param showEst If \code{TRUE} (default), the estimates are printed.
-#' @param showConfInt If \code{TRUE} (default), the confidence intervall is also printed to the table. Use
-#'          \code{FALSE} to omit the CI in the table.
-#' @param showStdBeta If \code{TRUE}, the standardized beta-coefficients are also printed.
-#'          Default is \code{FALSE}.
-#' @param showStdError If \code{TRUE}, the standard errors are also printed.
-#'          Default is \code{FALSE}.
-#' @param digits.est Amount of decimals for estimators.
-#' @param digits.p Amount of decimals for p-values.
-#' @param digits.ci Amount of decimals for confidence intervals.
-#' @param digits.se Amount of decimals for standard error.
-#' @param digits.sb Amount of decimals for standardized beta.
-#' @param digits.summary Amount of decimals for values in model summary.
-#' @param pvaluesAsNumbers If \code{TRUE}, p-values are shown as numbers. If \code{FALSE} (default),
-#'          p-values are indicated by asterisks.
-#' @param boldpvalues If \code{TRUE} (default), significant p-values are shown bold faced.
-#' @param separateConfColumn if \code{TRUE}, the CI values are shown in a separate table column.
-#'          Default is \code{FALSE}.
-#' @param newLineConf If \code{TRUE} and \code{separateConfColumn} is \code{FALSE}, inserts a line break
-#'          between B and CI values. If \code{FALSE}, CI values are printed in the same
-#'          line with B values.
-#' @param showAbbrHeadline If \code{TRUE} (default), the table data columns have a headline with 
-#'          abbreviations for beta- and std. beta-values, confidence interval and p-values.
-#' @param showICC If \code{TRUE}, the intra-class-correlation for each model is printed
-#'          in the model summary.
-#' @param showAIC If \code{TRUE}, the AIC value for each model is printed
-#'          in the model summary. Default is \code{FALSE}.
-#' @param remove.estimates numeric vector with indices (order equals to row index of \code{coef(fit)}) 
-#'          or character vector with coefficient names that indicate which estimates should be removed
-#'          from the table output. The first estimate is the intercept, followed by the model predictors.
-#'          \emph{The intercept cannot be removed from the table output!} \code{remove.estimates = c(2:4)} 
-#'          would remove the 2nd to the 4th estimate (1st to 3d predictor after intercept) from the output. 
-#'          \code{remove.estimates = "est_name"} would remove the estimate \emph{est_name}. Default 
-#'          is \code{NULL}, i.e. all estimates are printed.
-#' @param cellSpacing The inner padding of table cells. By default, this value is 0.2 (unit is cm), which is
-#'          suitable for viewing the table. Decrease this value (0.05 to 0.1) if you want to import the table
-#'          into Office documents. This is a convenient parameter for the \code{CSS} parameter for changing
-#'          cell spacing, which would be: \code{CSS=list(css.thead="padding:0.2cm;", css.tzdata="padding:0.2cm;")}.
-#' @param encoding The charset encoding used for variable and value labels. Default is \code{NULL}, so encoding
-#'          will be auto-detected depending on your platform (\code{"UTF-8"} for Unix and \code{"Windows-1252"} for
-#'          Windows OS). Change encoding if specific chars are not properly displayed (e.g.) German umlauts).
-#' @param CSS A \code{\link{list}} with user-defined style-sheet-definitions, according to the 
-#'          \href{http://www.w3.org/Style/CSS/}{official CSS syntax}. See 'Details'.
-#' @param useViewer If \code{TRUE}, the function tries to show the HTML table in the IDE's viewer pane. If
-#'          \code{FALSE} or no viewer available, the HTML table is opened in a web browser.
-#' @param no.output If \code{TRUE}, the html-output is neither opened in a browser nor shown in
-#'          the viewer pane and not even saved to file. This option is useful when the html output
-#'          should be used in \code{knitr} documents. The html output can be accessed via the return
-#'          value.
-#' @param remove.spaces logical, if \code{TRUE}, leading spaces are removed from all lines in the final string
-#'          that contains the html-data. Use this, if you want to remove parantheses for html-tags. The html-source
-#'          may look less pretty, but it may help when exporting html-tables to office tools.
+#' @inheritParams sjt.lm
+#' @inheritParams sjt.frq
+#' 
+#' @param showICC logical, if \code{TRUE}, the intra-class-correlation for each 
+#'          model is printed in the model summary.
 #' @return Invisibly returns
 #'          \itemize{
 #'            \item the web page style sheet (\code{page.style}),
@@ -1520,48 +1437,56 @@ sjt.lm <- function (...,
 #' sjt.lmer(fit1, fit2, fit3, 
 #'          showAIC = TRUE,
 #'          separateConfColumn = FALSE,
-#'          newLineConf = FALSE)}
+#'          newLineConf = FALSE)
+#'          
+#' sjt.lmer(fit1, fit2, fit3,
+#'          labelPredictors = c("Elder's gender (female)",
+#'                              "Hours of care per week",
+#'                              "Barthel Index",
+#'                              "Educational level (mid)",
+#'                              "Educational level (high)"))}
 #'                   
 #' @export
-sjt.lmer <- function(..., 
-                    file=NULL, 
-                    labelPredictors=NULL, 
-                    labelDependentVariables=NULL, 
-                    stringPredictors="Predictors", 
-                    stringDependentVariables="Dependent Variables", 
-                    stringModel="Model",
-                    showHeaderStrings=FALSE,
-                    stringIntercept="(Intercept)",
-                    stringObservations="Observations",
-                    stringB="B",
-                    stringSB="std. Beta",
-                    stringCI="CI",
-                    stringSE="std. Error",
-                    stringP="p",
-                    showEst=TRUE,
-                    showConfInt=TRUE,
-                    showStdBeta=FALSE,
-                    showStdError=FALSE,
-                    digits.est=2,
-                    digits.p=3,
-                    digits.ci=2,
-                    digits.se=2,
-                    digits.sb=2,
-                    digits.summary=3,
-                    pvaluesAsNumbers=TRUE,
-                    boldpvalues=TRUE,
-                    separateConfColumn=TRUE,
-                    newLineConf=TRUE,
-                    showAbbrHeadline=TRUE,
-                    showICC=TRUE,
-                    showAIC=FALSE,
-                    remove.estimates=NULL,
-                    cellSpacing=0.2,
-                    encoding=NULL,
-                    CSS=NULL,
-                    useViewer=TRUE,
-                    no.output=FALSE,
-                    remove.spaces=TRUE) {
+sjt.lmer <- function(...,
+                     file = NULL,
+                     labelPredictors = NULL,
+                     labelDependentVariables = NULL,
+                     stringPredictors = "Predictors",
+                     stringDependentVariables = "Dependent Variables",
+                     stringModel = "Model",
+                     showHeaderStrings = FALSE,
+                     stringIntercept = "(Intercept)",
+                     stringObservations = "Observations",
+                     stringB = "B",
+                     stringSB = "std. Beta",
+                     stringCI = "CI",
+                     stringSE = "std. Error",
+                     stringP = "p",
+                     showEst = TRUE,
+                     showConfInt = TRUE,
+                     showStdBeta = FALSE,
+                     showStdError = FALSE,
+                     digits.est = 2,
+                     digits.p = 3,
+                     digits.ci = 2,
+                     digits.se = 2,
+                     digits.sb = 2,
+                     digits.summary = 3,
+                     pvaluesAsNumbers = TRUE,
+                     boldpvalues = TRUE,
+                     separateConfColumn = TRUE,
+                     newLineConf = TRUE,
+                     showAbbrHeadline = TRUE,
+                     showICC = TRUE,
+                     showAIC = FALSE,
+                     showAICc = FALSE,
+                     remove.estimates = NULL,
+                     cellSpacing = 0.2,
+                     encoding = NULL,
+                     CSS = NULL,
+                     useViewer = TRUE,
+                     no.output = FALSE,
+                     remove.spaces = TRUE) {
   input_list <- list(...)
   return(sjt.lm(input_list, file = file, labelPredictors = labelPredictors, 
                 labelDependentVariables = labelDependentVariables, stringPredictors = stringPredictors, 
@@ -1575,7 +1500,7 @@ sjt.lmer <- function(...,
                 pvaluesAsNumbers = pvaluesAsNumbers, boldpvalues = boldpvalues, 
                 separateConfColumn = separateConfColumn, newLineConf = newLineConf, 
                 group.pred = FALSE, showAbbrHeadline = showAbbrHeadline, showR2 = showICC, 
-                showFStat = FALSE, showAIC = showAIC, remove.estimates = remove.estimates, 
+                showFStat = FALSE, showAIC = showAIC, showAICc = showAICc, remove.estimates = remove.estimates, 
                 cellSpacing = cellSpacing, cellGroupIndent = 0, encoding = encoding, 
                 CSS = CSS, useViewer = useViewer, no.output = no.output, remove.spaces = remove.spaces))
 }
\ No newline at end of file
